"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var definition_1 = require("../../../definition");
var enhanced_generic_component_1 = require("../../base/enhanced-generic.component");
var util_1 = require("../../../util");
var info_1 = require("../../info");
var Field = /** @class */ (function (_super) {
    __extends(Field, _super);
    function Field() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @stable [17.05.2020]
     * @param {ChangeEventT} event
     */
    Field.prototype.onChange = function (event) {
        this.onChangeValue(this.getRawValueFromEvent(event));
    };
    Field.prototype.setFocus = function () {
        // Do nothing
    };
    /**
     * @stable [17.05.2020]
     * @param {ChangeEventT} event
     * @returns {AnyT}
     */
    Field.prototype.getRawValueFromEvent = function (event) {
        return event.target.value;
    };
    /**
     * @stable [18.05.2020]
     * @param {AnyT} currentRawValue
     */
    Field.prototype.onChangeValue = function (currentRawValue) {
        var mergedProps = this.mergedProps;
        var actualFieldValue = util_1.FieldUtils.asActualFieldValue(__assign({}, mergedProps, { emptyValue: this.emptyValue, value: currentRawValue }));
        this.validateField(actualFieldValue);
        util_1.ConditionUtils.ifNotNilThanValue(mergedProps.onChange, function (onChange) { return onChange(actualFieldValue); });
        util_1.ConditionUtils.ifNotNilThanValue(mergedProps.onFormChange, function (onFormChange) { return onFormChange(mergedProps.name, actualFieldValue); });
    };
    Field.prototype.validateField = function (rawValue) {
        // TODO
    };
    /**
     * @stable [18.05.2020]
     * @param {AnyT} value
     * @param {boolean} forceApplyValue
     * @returns {AnyT}
     */
    Field.prototype.getDecoratedDisplayValue = function (value, forceApplyValue) {
        if (forceApplyValue === void 0) { forceApplyValue = false; }
        var displayValue = this.props.displayValue;
        return R.isNil(displayValue)
            ? this.decorateDisplayValue(value)
            : (util_1.TypeUtils.isFn(displayValue)
                ? util_1.CalcUtils.calc(displayValue, this.decorateDisplayValue(value))
                : this.decorateDisplayValue(forceApplyValue ? value : displayValue));
    };
    /**
     * @stable [18.05.2020]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    Field.prototype.decorateDisplayValue = function (value) {
        return value;
    };
    /**
     * @stable [18.05.2020]
     * @returns {FieldComposedInputAttributesT}
     */
    Field.prototype.getInputElementProps = function () {
        return {}; // TODO
    };
    Object.defineProperty(Field.prototype, "inputWrapperElement", {
        /**
         * @stable [18.05.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            if (this.isFieldRendered) {
                return (React.createElement("div", { className: definition_1.FieldClassesEnum.FIELD_INPUT_WRAPPER },
                    this.getInputElement(),
                    this.mirrorInputElement,
                    this.inputCaretElement,
                    this.inputAttachmentElement));
            }
            return this.inputAttachmentElement;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [18.05.2020]
     * @returns {JSX.Element}
     */
    Field.prototype.getInputElement = function () {
        return React.createElement("input", __assign({}, this.getInputElementProps()));
    };
    Object.defineProperty(Field.prototype, "inputAttachmentElement", {
        /**
         * @stable [18.05.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "mirrorInputElement", {
        /**
         * @stable [18.05.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "inputCaretElement", {
        /**
         * @stable [18.05.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "progressInfoElement", {
        /**
         * @stable [19.05.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return util_1.ConditionUtils.orNull(this.isFieldBusy(), function () { return React.createElement(info_1.Info, { progress: true }); });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "emptyValue", {
        /**
         * @stable [17.05.2020]
         * @returns {AnyT}
         */
        get: function () {
            var mergedProps = this.mergedProps;
            return util_1.TypeUtils.isDef(mergedProps.emptyValue) ? mergedProps.emptyValue : this.originalEmptyValue;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "originalEmptyValue", {
        /**
         * @stable [17.05.2020]
         * @returns {AnyT}
         */
        get: function () {
            return definition_1.FieldConstants.DISPLAY_EMPTY_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isFieldRendered", {
        /**
         * @stable [18.05.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.WrapperUtils.isFieldRendered(this.props);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [18.05.2020]
     * @param {AnyT} value
     * @returns {boolean}
     */
    Field.prototype.isValueObject = function (value) {
        return util_1.TypeUtils.isObject(value);
    };
    /**
     * @stable [18.05.2020]
     * @param {AnyT} value
     * @returns {boolean}
     */
    Field.prototype.isValueDefined = function (value) {
        return util_1.TypeUtils.isDef(value);
    };
    /**
     * @stable [19.05.2020]
     * @returns {boolean}
     */
    Field.prototype.isFieldBusy = function () {
        return util_1.WrapperUtils.inProgress(this.mergedProps);
    };
    Object.defineProperty(Field.prototype, "mergedProps", {
        /**
         * @stable [17.05.2020]
         * @returns {TProps}
         */
        get: function () {
            return util_1.PropsUtils.mergeWithSystemProps(this.props, this.settings.components.field);
        },
        enumerable: true,
        configurable: true
    });
    return Field;
}(enhanced_generic_component_1.EnhancedGenericComponent));
exports.Field = Field;
//# sourceMappingURL=field.component.js.map