"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var util_1 = require("../../../util");
var definitions_interface_1 = require("../../../definitions.interface");
var universal_field_component_1 = require("./universal-field.component");
var definition_1 = require("../../../definition");
var Field2 = /** @class */ (function (_super) {
    __extends(Field2, _super);
    /**
     * @stable [28.10.2019]
     * @param {TProps} props
     */
    function Field2(props) {
        var _this = _super.call(this, props) || this;
        _this.defaultActions = [];
        _this.inputRef = React.createRef();
        _this.onClick = _this.onClick.bind(_this);
        return _this;
    }
    /**
     * @stable [26.05.2019]
     * @returns {JSX.Element}
     */
    Field2.prototype.render = function () {
        return (React.createElement("div", { className: this.getFieldClassName(), onClick: util_1.cancelEvent },
            this.props.children,
            this.getDisplayValueElement(),
            this.selfElement,
            this.getMessageElement(),
            this.getErrorMessageElement(),
            this.getAttachmentElement(),
            this.getKeyboardElement()));
    };
    /**
     * @stable [29.10.2019]
     */
    Field2.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        this.onCloseVirtualKeyboard();
    };
    /**
     * @stable [07.01.2019]
     * @param {AnyT} currentRawValue
     */
    Field2.prototype.onChangeManually = function (currentRawValue) {
        this.updateInputBeforeHTML5Validation(currentRawValue);
        _super.prototype.onChangeManually.call(this, currentRawValue);
    };
    /**
     * @stable [17.06.2018]
     */
    Field2.prototype.resetError = function () {
        if (!R.isNil(this.input.required)) {
            // Because of Flux-architecture (chicken-and-egg dilemma)
            // This flag is being set by a redux engine on a new cycle
            // Need to reset: required, pattern, etc...
            this.input.required = false;
        }
        _super.prototype.resetError.call(this);
    };
    /**
     * @stable [03.09.2018]
     * @param {IKeyboardEvent} event
     */
    Field2.prototype.onKeyDown = function (event) {
        var key = event.key;
        switch (key) {
            case 'Tab':
                this.onKeyTab(event);
                break;
            case 'Enter':
                this.onKeyEnter(event);
                break;
            case 'Escape':
                this.onKeyEscape(event);
                break;
            case 'ArrowDown':
                this.onKeyArrowDown(event);
                break;
            case 'ArrowUp':
                this.onKeyArrowUp(event);
                break;
            case 'Backspace':
                this.onKeyBackspace(event);
                break;
        }
        _super.prototype.onKeyDown.call(this, event);
    };
    /**
     * @stable [29.10.2019]
     */
    Field2.prototype.setFocus = function () {
        var _this = this;
        util_1.ifNotNilThanValue(this.input, function (input) {
            if (!_this.isFocusPrevented) {
                input.focus();
            }
        });
    };
    Object.defineProperty(Field2.prototype, "input", {
        /**
         * @stable [28.10.2019]
         * @returns {InputElementT}
         */
        get: function () {
            return util_1.ifNotNilThanValue(this.inputRef.current, function (input) { return input.inputElement || input; });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [29.10.2019]
     * @returns {JSX.Element}
     */
    Field2.prototype.getKeyboardElement = function () {
        var _this = this;
        return util_1.orNull(this.isKeyboardUsed && this.isKeyboardOpen(), function () { return _this.keyboardElement; });
    };
    /**
     * @stable [03.09.2018]
     * @returns {JSX.Element}
     */
    Field2.prototype.getErrorMessageElement = function () {
        return this.isErrorMessageRendered
            ? this.toMessageElement(this.error, 'rac-field-error-text')
            : null;
    };
    Object.defineProperty(Field2.prototype, "selfElement", {
        /**
         * @stable [22.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var props = this.props;
            if (this.isFieldRendered) {
                return (React.createElement("div", { ref: this.actualRef, style: props.style, title: this.getTitle(), className: this.getSelfElementClassName() },
                    this.prefixLabelElement,
                    this.inputWrapperElement,
                    this.actionsElement,
                    this.labelElement,
                    this.progressInfoElement));
            }
            return this.inputWrapperElement;
        },
        enumerable: true,
        configurable: true
    });
    Field2.prototype.getTitle = function () {
        var _this = this;
        return this.props.title || util_1.orNull(this.isFocusPrevented, function () { return _this.displayValue; });
    };
    Object.defineProperty(Field2.prototype, "labelElement", {
        get: function () {
            var _this = this;
            return util_1.ifNotNilThanValue(this.getLabel(), function (label) { return (React.createElement("label", { className: 'rac-field-label' }, _this.t(label))); });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [16.02.2020]
     * @returns {JSX.Element}
     */
    Field2.prototype.getAttachmentElement = function () {
        return null;
    };
    Object.defineProperty(Field2.prototype, "hasInput", {
        /**
         * @stable [28.10.2019]
         * @returns {boolean}
         */
        get: function () {
            return !R.isNil(this.inputRef.current);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [20.08.2018]
     */
    Field2.prototype.removeFocus = function () {
        var input = this.input;
        if (!R.isNil(input)) {
            input.blur();
        }
    };
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    Field2.prototype.onClick = function (event) {
        this.domAccessor.cancelEvent(event);
        var props = this.props;
        if (util_1.isFn(props.onClick)) {
            props.onClick(event);
        }
    };
    /**
     * @stable [30.10.2019]
     * @returns {FieldComposedInputAttributesT}
     */
    Field2.prototype.getInputElementProps = function () {
        var _this = this;
        var props = this.props;
        /**/
        var autoComplete = props.autoComplete || 'off'; /* @stable [29.10.2019] */
        var cols = props.cols; /* @stable [28.10.2019] */
        var disabled = this.isDisabled; /* @stable [28.10.2019] */
        var maxLength = props.maxLength; /* @stable [28.10.2019] */
        var minLength = props.minLength; /* @stable [28.10.2019] */
        var name = props.name; /* @stable [28.10.2019] */
        var pattern = this.getFieldPattern(); /* @stable [29.10.2019] */
        var placeholder = util_1.orUndef(props.placeholder && !this.isFieldBusy(), function () { return _this.t(props.placeholder); }); /* @stable [29.10.2019] */
        var readOnly = this.isInactive; /* @stable [28.10.2019] */
        var required = this.isRequired; /* @stable [29.10.2019] */
        var rows = props.rows; /* @stable [28.10.2019] */
        var step = props.step; /* @stable [28.10.2019] */
        var tabIndex = props.tabIndex; /* @stable [28.10.2019] */
        var type = props.type || 'text'; /* @stable [28.10.2019] */
        var value = this.displayValue; /* @stable [28.10.2019] */
        var result = util_1.defValuesFilter(__assign({ className: 'rac-field-input rac-flex-x1', autoComplete: autoComplete, cols: cols, disabled: disabled, maxLength: maxLength, minLength: minLength, name: name, pattern: pattern,
            placeholder: placeholder, readOnly: readOnly, rows: rows, step: step, tabIndex: tabIndex, type: type, value: value, required: required }, (this.isActive
            ? {
                onBlur: this.onBlur,
                onChange: this.onChange,
                onClick: this.onClick,
                onFocus: this.onFocus,
                onKeyDown: this.onKeyDown,
                onKeyUp: this.onKeyUp,
            }
            : {})));
        return __assign({}, result, { ref: this.inputRef });
    };
    /**
     * @stable [06.10.2018]
     * @returns {string}
     */
    Field2.prototype.getFieldClassName = function () {
        var props = this.props;
        return util_1.joinClassName('rac-field', util_1.isFull(props) && definition_1.ComponentClassesEnum.FLEX_X1, // TODO full-field
        this.isRequired && 'rac-field-required', this.isFieldBusy() && 'rac-field-busy', this.isFieldInvalid() && 'rac-field-invalid', this.isValuePresent ? 'rac-field-value-present' : 'rac-field-value-not-present', this.isChangeable ? 'rac-field-changeable' : 'rac-field-not-changeable', this.isFocused ? 'rac-field-focused' : 'rac-field-not-focused', this.isDisabled && 'rac-field-disabled', this.isReadOnly && 'rac-field-readonly', this.isFocusPrevented && 'rac-field-prevent-focus', !R.isEmpty(this.getFieldActions()) && 'rac-field-actioned', props.label && 'rac-field-labeled', props.prefixLabel ? 'rac-field-label-prefixed' : 'rac-field-label-not-prefixed', util_1.calc(props.className));
    };
    /**
     * @stable [06.05.2020]
     * @returns {string}
     */
    Field2.prototype.getSelfElementClassName = function () {
        return definition_1.FieldClassesEnum.FIELD_SELF;
    };
    /**
     * @stable [31.07.2018]
     * @returns {boolean}
     */
    Field2.prototype.isInputValid = function () {
        return !this.hasInput || this.input.validity.valid;
    };
    /**
     * @stable [31.07.2018]
     * @returns {string}
     */
    Field2.prototype.getNativeInputValidationMessage = function () {
        return this.input.validationMessage;
    };
    /**
     * @stable [31.07.2018]
     * @param {string} error
     */
    Field2.prototype.setNativeInputValidity = function (error) {
        if (this.hasInput) {
            this.input.setCustomValidity(error);
        }
    };
    /**
     * @stable [03.09.2018]
     * @param {string} message
     * @param {string} className
     * @returns {JSX.Element}
     */
    Field2.prototype.toMessageElement = function (message, className) {
        return (React.createElement("div", { title: message, className: util_1.joinClassName('rac-field-help-text', className) }, message ? this.t(message) : definitions_interface_1.UniCodesEnum.NO_BREAK_SPACE));
    };
    /**
     * @stable [30.10.2019]
     * @returns {IFieldActionEntity[]}
     */
    Field2.prototype.getFieldActions = function () {
        var props = this.props;
        var defaultActions = this.defaultActions || [];
        var actions = props.actions || [];
        return props.actionsPosition === definition_1.FieldActionPositionsEnum.LEFT
            ? defaultActions.concat(actions)
            : actions.concat(defaultActions);
    };
    /**
     * @stable [17.06.2018]
     * @param {AnyT} value
     */
    Field2.prototype.updateInputBeforeHTML5Validation = function (value) {
        if (this.hasInput) {
            // We must update the field manually before calls HTML5 validation
            this.input.value = value;
        }
    };
    Object.defineProperty(Field2.prototype, "jqInput", {
        /**
         * @stable [29.09.2019]
         * @returns {IJQueryElement}
         */
        get: function () {
            return this.domAccessor.asJqEl(this.input);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field2.prototype, "isErrorMessageRendered", {
        /**
         * @stable [16.02.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isErrorMessageRendered(this.systemProps) && util_1.isErrorMessageRendered(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field2.prototype, "systemProps", {
        /**
         * @stable [16.02.2020]
         * @returns {TProps}
         */
        get: function () {
            var _a = (this.settings.components || {}).field, field = _a === void 0 ? {} : _a;
            return field;
        },
        enumerable: true,
        configurable: true
    });
    return Field2;
}(universal_field_component_1.UniversalField));
exports.Field2 = Field2;
//# sourceMappingURL=field2.component.js.map