"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var ts_smart_logger_1 = require("ts-smart-logger");
var definition_1 = require("../../definition");
var util_1 = require("../../util");
var base_1 = require("../base");
var button_1 = require("../button");
var field_1 = require("../field");
var di_1 = require("../../di");
var Form = /** @class */ (function (_super) {
    __extends(Form, _super);
    /**
     * @stable [08.05.2020]
     * @param {IFormProps} props
     */
    function Form(props) {
        var _this = _super.call(this, props) || this;
        _this.doSubmit = _this.doSubmit.bind(_this);
        _this.onChange = _this.onChange.bind(_this);
        _this.onReset = _this.onReset.bind(_this);
        _this.onSubmit = _this.onSubmit.bind(_this);
        return _this;
    }
    /**
     * @stable [30.01.2020]
     * @returns {JSX.Element}
     */
    Form.prototype.render = function () {
        var props = this.props;
        var formId = props.formId;
        var nodes = this.formNodes;
        var formElement = (React.createElement("form", { ref: this.selfRef, style: props.style, autoComplete: 'off', onReset: this.onReset, onSubmit: this.onSubmit, className: this.className },
            util_1.isCompact(props)
                ? nodes
                : (React.createElement("div", { className: definition_1.FormClassesEnum.FORM_BODY }, nodes)),
            util_1.isActionsRendered(props) && (React.createElement("div", { className: definition_1.FormClassesEnum.FORM_ACTIONS }, this.formActionsElement))));
        if (R.isNil(formId)) {
            return formElement;
        }
        return (React.createElement(definition_1.UniversalIdProviderContext.Provider, { value: formId }, formElement));
    };
    /**
     * @stable [30.01.2020]
     */
    Form.prototype.componentDidMount = function () {
        if (util_1.isValidateOnMount(this.props)) {
            this.throwOnValid();
        }
    };
    /**
     * @stable [23.04.2020]
     */
    Form.prototype.submit = function () {
        var onSubmit = this.props.onSubmit;
        if (util_1.isFn(onSubmit)) {
            onSubmit(this.apiEntity);
        }
    };
    /**
     * @stable [23.04.2020]
     * @param {string} name
     * @param {AnyT} value
     */
    Form.prototype.onChange = function (name, value) {
        var _a;
        var onChange = this.props.onChange;
        if (util_1.isFn(onChange)) {
            if (util_1.isObjectNotEmpty(name)) {
                onChange((_a = {}, _a[name] = value, _a));
                this.throwOnValid();
            }
            else {
                Form.logger.warn('[$Form][onChange] The field has no name. The field value:', value);
            }
        }
    };
    /**
     * @stable [09.05.2020]
     * @param {IField} field
     */
    Form.prototype.onFieldDictionaryEmpty = function (field) {
        var onDictionaryEmpty = this.props.onDictionaryEmpty;
        if (util_1.isFn(onDictionaryEmpty)) {
            onDictionaryEmpty(field.props.bindDictionary, this.apiEntity);
        }
    };
    /**
     * @stable [09.05.2020]
     * @param {IField} field
     * @param {AnyT} items
     */
    Form.prototype.onFieldDictionaryLoad = function (field, items) {
        var onDictionaryLoad = this.props.onDictionaryLoad;
        if (util_1.isFn(onDictionaryLoad)) {
            onDictionaryLoad(items, field.props.bindDictionary);
        }
    };
    /**
     * @stable [03.02.2020]
     */
    Form.prototype.throwOnValid = function () {
        var _a = this.props, onValid = _a.onValid, valid = _a.valid;
        if (util_1.isFn(onValid)) {
            onValid(util_1.isBoolean(valid) || this.selfRef.current.checkValidity());
        }
    };
    /**
     * @stable [30.01.2020]
     */
    Form.prototype.doSubmit = function () {
        this.onSubmit();
    };
    /**
     * @stable [03.02.2020]
     * @param {IBaseEvent} event
     */
    Form.prototype.onSubmit = function (event) {
        this.domAccessor.cancelEvent(event);
        var onBeforeSubmit = this.props.onBeforeSubmit;
        var apiEntity = this.apiEntity;
        if (util_1.isFn(onBeforeSubmit)) {
            if (onBeforeSubmit(apiEntity) !== false) {
                this.submit();
            }
        }
        else {
            this.submit();
        }
    };
    /**
     * @stable [30.01.2020]
     * @param {IBaseEvent} event
     */
    Form.prototype.onReset = function (event) {
        this.domAccessor.cancelEvent(event);
        var onReset = this.props.onReset;
        if (util_1.isFn(onReset)) {
            onReset();
        }
    };
    Object.defineProperty(Form.prototype, "isFormValid", {
        /**
         * @stable [11.05.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.FormUtils.isValid(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "isFormSubmittable", {
        /**
         * @stable [23.03.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isFormSubmittable(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "isFormResettable", {
        /**
         * @stable [23.03.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isFormResettable(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "isFormOfNewEntity", {
        /**
         * @stable [03.02.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isNewEntity(this.props.entity);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "isFormBusy", {
        /**
         * @stable [11.05.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.FormUtils.inProgress(this.props);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [25.09.2019]
     * @param {IField} field
     * @returns {boolean}
     */
    Form.prototype.isFieldReadOnly = function (field) {
        return util_1.isFormFieldReadOnly(this.props, field.props);
    };
    /**
     * @stable [23.03.2020]
     * @param {IField} field
     * @returns {boolean}
     */
    Form.prototype.isFieldDisabled = function (field) {
        return util_1.isFormFieldDisabled(this.props, field.props);
    };
    /**
     * @stable [23.03.2020]
     * @param {IField} field
     * @returns {boolean}
     */
    Form.prototype.isFieldChangeable = function (field) {
        return util_1.isFormFieldChangeable(this.props, field.props);
    };
    /**
     * @stable [16.11.2019]
     * @param {IField} field
     * @returns {AnyT}
     */
    Form.prototype.getFieldValue = function (field) {
        return util_1.getFormFieldValue(this.props, field.props);
    };
    /**
     * @stable [11.05.2020]
     * @param {IField} field
     * @returns {AnyT}
     */
    Form.prototype.getFieldOriginalValue = function (field) {
        return util_1.FormUtils.fieldOriginalValue(this.props, field.props);
    };
    /**
     * @stable [11.05.2020]
     * @param {IField} field
     * @param {IFieldProps} defaultProps
     * @returns {AnyT}
     */
    Form.prototype.getFieldDisplayValue = function (field, defaultProps) {
        return util_1.FormUtils.fieldDisplayValue(this.props, field.props, defaultProps);
    };
    /**
     * @stable [03.02.2020]
     * @param {IField} field
     * @returns {IFieldProps2}
     */
    Form.prototype.getPredefinedFieldProps = function (field) {
        var props = this.fieldsPresets[field.props.name];
        var resultProps;
        if (util_1.TypeUtils.isString(props)) {
            resultProps = { label: props };
        }
        else if (util_1.isFn(props)) {
            resultProps = props(field);
        }
        else {
            resultProps = props;
        }
        return resultProps;
    };
    Object.defineProperty(Form.prototype, "formActionsElement", {
        /**
         * @stable [13.02.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            var props = this.props;
            var actions = this.actions;
            var actualActions = util_1.isFn(props.actionsFactory) ? props.actionsFactory(actions) : actions;
            return (React.createElement(React.Fragment, null, actualActions
                .map(function (action, index) { return (React.createElement(button_1.Button, __assign({ key: "form-action-" + (action.text || index) }, action, { onClick: util_1.ifNotNilThanValue(action.onClick, function () { return function () { return action.onClick(_this.apiEntity); }; }) }))); })));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "formNodes", {
        /**
         * @stable [03.02.2020]
         * @returns {React.ReactNode[]}
         */
        get: function () {
            var _this = this;
            return (util_1.cloneReactNodes(this, function (field) {
                var fieldProps = field.props;
                var predefinedOptions = _this.getPredefinedFieldProps(field);
                return util_1.defValuesFilter(__assign({ value: _this.getFieldValue(field), originalValue: _this.getFieldOriginalValue(field), displayValue: _this.getFieldDisplayValue(field, predefinedOptions), readOnly: _this.isFieldReadOnly(field), disabled: _this.isFieldDisabled(field), changeable: _this.isFieldChangeable(field), onFormChange: _this.onChange }, (fieldProps.bindDictionary && (__assign({}, (!util_1.isFn(fieldProps.onDictionaryEmpty)
                    ? ({ onDictionaryEmpty: function () { return _this.onFieldDictionaryEmpty(field); } })
                    : {}), (!util_1.isFn(fieldProps.onDictionaryLoad)
                    ? ({ onDictionaryLoad: function (itms) { return _this.onFieldDictionaryLoad(field, itms); } })
                    : {})))), predefinedOptions, util_1.defValuesFilter({
                    label: fieldProps.label,
                    placeholder: fieldProps.placeholder,
                    prefixLabel: fieldProps.prefixLabel,
                    type: fieldProps.type,
                })));
            }, function (child) { return field_1.Field2.isPrototypeOf(child.type); }, function (child) { return child.props.rendered; }));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "hasError", {
        /**
         * @stable [03.02.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isObjectNotEmpty(util_1.selectError(this.form));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "actions", {
        /**
         * @stable [13.02.2020]
         * @returns {IButtonProps[]}
         */
        get: function () {
            var _this = this;
            var props = this.props;
            var _a = props.buttonConfiguration, buttonConfiguration = _a === void 0 ? {} : _a, _b = props.resetConfiguration, resetConfiguration = _b === void 0 ? {} : _b, _c = props.submitConfiguration, submitConfiguration = _c === void 0 ? {} : _c;
            var messages = this.settings.messages;
            return util_1.FilterUtils.objectValuesArrayFilter(props.resetActionRendered && util_1.notNilValuesFilter(__assign({ type: 'reset', icon: props.resetIcon || definition_1.IconsEnum.TIMES, disabled: !this.isFormResettable, text: props.resetText || messages.RESET }, buttonConfiguration, resetConfiguration, { onClick: null })), util_1.notNilValuesFilter(__assign({ type: 'submit', icon: this.isFormValid ? (props.submitIcon || definition_1.IconsEnum.CHECK_CIRCLE) : 'exclamation', raised: true, disabled: !this.isFormSubmittable, progress: this.isFormBusy, error: this.hasError, text: props.submitText || (this.isFormOfNewEntity ? messages.CREATE : messages.SAVE) }, buttonConfiguration, submitConfiguration, { onClick: util_1.orNull(submitConfiguration.type === 'button', function () { return _this.doSubmit; }) })));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "apiEntity", {
        /**
         * @stable [18.04.2020]
         * @returns {IApiEntity}
         */
        get: function () {
            return util_1.mapApiEntity({
                changes: util_1.selectChanges(this.form),
                entity: this.entity,
                originalEntity: this.originalEntity,
            });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "className", {
        /**
         * @stable [18.04.2020]
         * @returns {string}
         */
        get: function () {
            var props = this.props;
            return util_1.joinClassName(definition_1.FormClassesEnum.FORM, util_1.isFull(props) && definition_1.FormClassesEnum.FULL_FORM, util_1.calc(props.className));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "form", {
        /**
         * @stable [18.04.2020]
         * @returns {IReduxFormEntity<IEntity>}
         */
        get: function () {
            return this.props.form;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "originalEntity", {
        /**
         * @stable [18.04.2020]
         * @returns {IEntity}
         */
        get: function () {
            return this.props.originalEntity;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "entity", {
        /**
         * @stable [18.04.2020]
         * @returns {IEntity}
         */
        get: function () {
            return this.props.entity;
        },
        enumerable: true,
        configurable: true
    });
    Form.logger = ts_smart_logger_1.LoggerFactory.makeLogger('Form');
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.FieldsPresets),
        __metadata("design:type", Object)
    ], Form.prototype, "fieldsPresets", void 0);
    return Form;
}(base_1.GenericComponent));
exports.Form = Form;
//# sourceMappingURL=form.component.js.map