import { DatesRangeValueT, IDatesRangeEntity, IExtendedLabeledValueEntity, IFieldConverter, IFieldConverterConfigEntity, INamedEntity, IReduxUserEntity, MultiFieldEntityT, PlaceEntityValueT, SelectValueT, TranslatorT } from '../../definition';
import { AnyT, EntityIdT, IEntity, StringNumberT } from '../../definitions.interface';
export declare class FieldConverter implements IFieldConverter {
    private static readonly logger;
    protected readonly t: TranslatorT;
    protected readonly converters: Map<string, (value: any) => any>;
    /**
     * @stable [09.01.2020]
     */
    constructor();
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     */
    register(config: IFieldConverterConfigEntity): void;
    /**
     * @stable [24.12.2019]
     * @param {IPhoneConfigEntity<libphonenumber.PhoneNumberFormat>} config
     * @returns {string}
     */
    convert(config: IFieldConverterConfigEntity): AnyT;
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     * @returns {(value: AnyT) => AnyT}
     */
    converter(config: IFieldConverterConfigEntity): (value: AnyT) => AnyT;
    /**
     * @stable [16.05.2020]
     * @param {SelectValueT} value
     * @returns {EntityIdT}
     */
    fromSelectOptionEntityToId(value: SelectValueT): EntityIdT;
    /**
     * @stable [18.05.2020]
     * @param {SelectValueT} value
     * @returns {StringNumberT}
     */
    fromSelectOptionEntityToDisplayValue(value: SelectValueT): StringNumberT;
    /**
     * @stable [17.05.2020]
     * @param {PlaceEntityValueT} value
     * @returns {string}
     */
    fromPlaceEntityToDisplayValue(value: PlaceEntityValueT): string;
    /**
     * @stable [17.05.2020]
     * @param {PlaceEntityValueT} value
     * @returns {string}
     */
    fromPlaceEntityToPlaceParameter(value: PlaceEntityValueT): string;
    /**
     * @stable [14.03.2020]
     * @param {TValue} value
     * @returns {IReduxUserEntity}
     */
    fromOAuthJwtDecodedInfoToUserEntity<TValue = AnyT>(value: TValue): IReduxUserEntity;
    /**
     * @stable [22.04.2020]
     * @param {INamedEntity} value
     * @returns {IExtendedLabeledValueEntity}
     */
    fromNamedEntityToExtendedLabeledValueEntity(value: INamedEntity): IExtendedLabeledValueEntity;
    /**
     * @stable [13.04.2020]
     * @nullable
     * @param {string} value
     * @returns {string}
     */
    fromCronExpressionToCronParameter(value: string): string;
    /**
     * @stable [16.05.2020]
     * @param {MultiFieldEntityT<TEntity extends IEntity>} value
     * @returns {TEntity[]}
     */
    fromMultiFieldEntityToEntities<TEntity extends IEntity = IEntity>(value: MultiFieldEntityT<TEntity>): TEntity[];
    /**
     * @stable [16.05.2020]
     * @param {MultiFieldEntityT<TEntity extends IEntity>} value
     * @returns {TEntity[]}
     */
    fromMultiFieldEntityToDefinedEntities<TEntity extends IEntity = IEntity>(value: MultiFieldEntityT<TEntity>): TEntity[];
    /**
     * @stable [28.01.2020]
     * @param {PlaceEntityValueT} placeEntity
     * @returns {string}
     */
    protected zipCodeEntityAsDisplayValue(placeEntity: PlaceEntityValueT): string;
    /**
     * @stable [18.05.2020]
     * @param {SelectValueT} option
     * @returns {StringNumberT}
     */
    protected $fromSelectOptionEntityToDisplayValue(option: SelectValueT): StringNumberT;
    /**
     * @stable [07.03.2020]
     * @param {IDatesRangeEntity} entity
     * @returns {DatesRangeValueT}
     */
    protected datesRangeEntityAsDatesRangeValue(entity: IDatesRangeEntity): DatesRangeValueT;
    /**
     * @stable [07.03.2020]
     * @param {DatesRangeValueT} value
     * @returns {IDatesRangeEntity}
     */
    protected datesRangeValueAsDatesRangeEntity(value: DatesRangeValueT): IDatesRangeEntity;
    /**
     * @stable [14.03.2020]
     * @param {TValue} value
     * @returns {IReduxUserEntity}
     */
    private $fromOAuthJwtDecodedInfoToUserEntity;
    /**
     * @stable [13.04.2020]
     * @nullable
     * @param {string} value
     * @returns {string}
     */
    private $fromCronExpressionToCronParameter;
    /**
     * @stable [22.04.2020]
     * @param {INamedEntity} value
     * @returns {IExtendedLabeledValueEntity}
     */
    private $fromNamedEntityToExtendedLabeledValueEntity;
    /**
     * @stable [17.05.2020]
     * @param {PlaceEntityValueT} placeEntity
     * @returns {string}
     */
    private $fromPlaceEntityToDisplayValue;
    /**
     * @stable [17.05.2020]
     * @param {PlaceEntityValueT} placeEntity
     * @returns {string}
     */
    private $fromPlaceEntityToPlaceParameter;
    /**
     * @stable [16.05.2020]
     * @param {MultiFieldEntityT<TEntity extends IEntity>} value
     * @returns {TEntity[]}
     */
    private $fromMultiFieldEntityToEntities;
    /**
     * @stable [16.05.2020]
     * @param {MultiFieldEntityT<TEntity extends IEntity>} value
     * @returns {TEntity[]}
     */
    private $fromMultiFieldEntityToDefinedEntities;
    /**
     * @stable [18.05.2020]
     * @param {SelectValueT} option
     * @returns {EntityIdT}
     */
    private $fromSelectOptionEntityToId;
    /**
     * @stable [16.05.2020]
     * @param {IFieldConverterConfigEntity} config
     * @returns {string}
     */
    private asKey;
}
