import { InputHTMLAttributes, RefAttributes, TextareaHTMLAttributes } from 'react';
import { AnyT, EntityIdT, IActionsPosition, IActionsWrapper, IAutoCompleteWrapper, IAutoFocusWrapper, IBindDictionaryWrapper, IChangeableWrapper, IClassNameWrapper, IDefaultValueWrapper, IDelayTimeoutWrapper, IDisabledWrapper, IDisableLabelWrapper, IDisplayNameWrapper, IDisplayValueRenderedOnlyWrapper, IDisplayValueWrapper, IEmptyValueWrapper, IEntity, IFieldRenderedWrapper, IFieldsWrapper, IFormatWrapper, IFullWrapper, IKeepChangesWrapper, ILabelWrapper, IMaskGuideWrapper, IMaskWrapper, IMenuRenderedWrapper, INameWrapper, IOnChangeWrapper, IOnClickWrapper, IOnDelayWrapper, IOnDictionaryEmptyWrapper, IOnDictionaryLoadWrapper, IOnFormChangeWrapper, IOriginalValueWrapper, IPatternWrapper, IPlaceholderWrapper, IPlainValueWrapper, IPrefixLabelWrapper, IPreventFocusWrapper, IPreventManualChangesWrapper, IProgressWrapper, IRawDataWrapper, IReadOnlyWrapper, IRenderedWrapper, IRequiredWrapper, IStepWrapper, ISyntheticCursorWrapper, ITabIndexWrapper, ITitleWrapper, ITypeWrapper, IUseKeyboardWrapper, IValidWrapper, IValueWrapper, StringNumberT } from '../definitions.interface';
import { IBaseSelectProps } from '../component/field/select/base-select.interface';
import { DatesRangeValueT, DateTimeLikeTypeT } from './date-definition.interface';
import { IComponentCtor } from './component-definition.interface';
import { IReduxLifeCycleEntity, IReduxMultiEntity } from './entity-definition.interface';
import { IFieldProps2 } from '../configurations-definitions.interface';
import { IGenericComponent, IGenericComponentProps } from './generic-component-definition.interface';
import { IApiEntity } from './api-definition.interface';
/**
 * @stable [16.05.2020]
 */
export declare class FieldConstants {
    static readonly DISPLAY_EMPTY_VALUE: string;
    static readonly ENTITY_ID_FIELD_NAME: string;
    static readonly ID_FIELD_NAME: string;
    static readonly VALUE_TO_CLEAR_DIRTY_CHANGES: any;
    static readonly VALUE_TO_RESET: any;
}
/**
 * @presets-entity
 * @stable [09.05.2020]
 */
export interface IPresetsFieldEntity extends IActionsWrapper<IFieldActionEntity[]>, IAutoFocusWrapper, IBindDictionaryWrapper, IDelayTimeoutWrapper, IDisplayNameWrapper, IDisplayValueWrapper<string | ((value: AnyT) => string)>, IEmptyValueWrapper, IFormatWrapper, IFullWrapper, IKeepChangesWrapper, ILabelWrapper, IMaskWrapper, INameWrapper, IOnChangeWrapper, IOnDelayWrapper, IOnDictionaryEmptyWrapper<string, IApiEntity>, IOnDictionaryLoadWrapper<{}, string>, IOnFormChangeWrapper, IPatternWrapper, IPlaceholderWrapper, IPlainValueWrapper, IPrefixLabelWrapper, IPreventFocusWrapper, IReadOnlyWrapper, IRenderedWrapper, IRequiredWrapper, ITypeWrapper<StringNumberT> {
}
/**
 * @presets-entity
 * @stable [19.05.2020]
 */
export interface IPresetsBaseTextFieldEntity extends IPresetsFieldEntity, IMaskGuideWrapper {
}
/**
 * @redux-entity
 * @stable [08.05.2020]
 */
export interface IReduxFieldEntity extends IReduxLifeCycleEntity, IOriginalValueWrapper, IValueWrapper {
}
/**
 * @redux-entity
 * @stable [19.05.2020]
 */
export interface IReduxBaseTextFieldEntity extends IReduxFieldEntity {
}
/**
 * @generic-entity
 * @stable [09.05.2020]
 */
export interface IGenericFieldEntity extends IPresetsFieldEntity, IReduxFieldEntity {
}
export interface IGenericFieldEntity2 extends IGenericFieldEntity, IActionsPosition<FieldActionPositionsEnum>, IAutoCompleteWrapper, IChangeableWrapper, IDefaultValueWrapper, IDisabledWrapper, IDisplayValueRenderedOnlyWrapper, IFieldRenderedWrapper, IPreventManualChangesWrapper, /* @stable [03.02.2020] */ IStepWrapper, ISyntheticCursorWrapper, ITabIndexWrapper, IUseKeyboardWrapper, IValidWrapper {
}
/**
 * @behavioral-entity
 * @stable [02.02.2020]
 */
export interface IBehavioralBaseFieldEntity extends IOnChangeWrapper {
}
/**
 * @behavioral-entity
 * @stable [02.02.2020]
 */
export interface IBehavioralFieldEntity extends IOnClickWrapper {
}
/**
 * @entity
 * @stable [28.09.2019]
 */
export interface IFieldChangeEntity extends INameWrapper, IValueWrapper, IRawDataWrapper {
}
/**
 * @flux-entity
 * @stable [08.05.2020]
 */
export interface IFluxFieldsChangesEntity extends IFieldsWrapper {
}
/**
 * @props
 * @stable [09.05.2020]
 */
export interface IFieldProps extends IGenericComponentProps, IGenericFieldEntity {
}
/**
 * @component
 * @stable [09.05.2020]
 */
export interface IField<TProps extends IFieldProps = IFieldProps, TState = {}> extends IGenericComponent<TProps, TState>, IOnChangeWrapper, IValueWrapper {
}
/**
 * @stable [02.10.2019]
 */
export declare type MultiFieldEntityT<TEntity extends IEntity = IEntity> = TEntity[] | IReduxMultiEntity;
export declare type MultiFieldSingleValueT = IReduxMultiEntity | EntityIdT;
export declare type NotMultiFieldEntityT<TEntity extends IEntity = IEntity> = TEntity[] | EntityIdT;
/**
 * @stable [30.10.2019]
 */
export declare enum FieldActionTypesEnum {
    ATTACH_FILE = "paperclip",
    CALENDAR = "calendar-alt-regular",
    CLOSE = "times",
    DOWNLOAD = "file-download",
    DROP_DOWN = "chevron-down",
    VIDEO = "video"
}
/**
 * @entity
 * @stable [06.05.2020]
 */
export interface IFieldActionEntity extends IClassNameWrapper, IDisabledWrapper<boolean | (() => boolean)>, IOnClickWrapper, ITitleWrapper, ITypeWrapper {
}
/**
 * @stable [09.05.2018]
 */
export interface IMaskedInputCtor extends IComponentCtor {
    inputElement: HTMLInputElement;
}
/**
 * @stable [18.05.2020]
 */
export interface IFieldInputAttributes extends InputHTMLAttributes<HTMLInputElement>, RefAttributes<HTMLInputElement> {
}
/**
 * @stable [18.05.2020]
 */
export interface IFieldTextAreaAttributes extends TextareaHTMLAttributes<HTMLTextAreaElement>, RefAttributes<HTMLTextAreaElement> {
}
/**
 * @stable [18.05.2020]
 */
export declare type FieldComposedInputAttributesT = IFieldInputAttributes | IFieldTextAreaAttributes;
/**
 * @stable [30.10.2019]
 */
export declare enum FieldActionPositionsEnum {
    LEFT = 0,
    RIGHT = 1
}
export interface IFieldsPresets {
    [fieldName: string]: string | IFieldProps2 | ((field: any) => IFieldProps2 | string);
}
/**
 * @default-entity
 * @stable [24.11.2019]
 */
export declare const DEFAULT_NO_AUTO_COMPLETE_FIELD_ENTITY: Readonly<IGenericFieldEntity2>;
/**
 * @default-entity
 * @stable [24.11.2019]
 */
export declare const DEFAULT_PASSWORD_FIELD_ENTITY: Readonly<IGenericFieldEntity2>;
/**
 * @stable [06.03.2020]
 */
export declare type DateFieldRangeValueT = DatesRangeValueT | DateTimeLikeTypeT;
/**
 * @generic-entity
 * @stable [07.01.2020]
 */
export interface IGenericBaseCheckboxEntity extends IDisableLabelWrapper {
}
/**
 * @generic-state
 * @stable [11.01.2020]
 */
export interface IGenericBaseSelectState extends IMenuRenderedWrapper, IProgressWrapper {
}
/**
 * @default-entity
 * @stable [19.05.2020]
 */
export declare const DEFAULT_QUICK_SEARCH_FIELD_ENTITY: Readonly<IBaseSelectProps>;
/**
 * @default-entity
 * @stable [16.04.2020]
 */
export declare const DEFAULT_NOT_CHANGEABLE_FIELD_ENTITY: Readonly<IGenericFieldEntity2>;
/**
 * @classes
 * @stable [26.03.2020]
 */
export declare enum FieldClassesEnum {
    FIELD_INPUT_WRAPPER = "rac-field__input-wrapper",
    FIELD_SELF = "rac-field__self"
}
