"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var cond_1 = require("./cond");
var wrapper_1 = require("./wrapper");
var type_1 = require("./type");
var nvl_1 = require("./nvl");
var tab_1 = require("./tab");
var select_1 = require("./select");
var form_entity_1 = require("./form-entity");
/**
 * @stable [11.05.2020]
 * @param {IFormProps<TEntity>} entity
 * @returns {boolean}
 */
var isFormValid = function (entity) {
    return wrapper_1.isValid(entity) && form_entity_1.FormEntityUtils.inValid(entity);
};
/**
 * @stable [06.05.2020]
 * @param {IExtendedFormEntity<TEntity>} formEntity
 * @param {string} fieldName
 * @returns {AnyT}
 */
var getFieldValueByName = function (formEntity, fieldName) { return (cond_1.ifNotEmptyThanValue(fieldName, function () { return (cond_1.ifNotNilThanValue((R.isNil(formEntity.entity)
    ? select_1.Selectors.formEntityChanges(formEntity)
    : formEntity.entity), function (data) { return data[fieldName]; }, definitions_interface_1.UNDEF_SYMBOL)); }, definitions_interface_1.UNDEF_SYMBOL)); };
/**
 * @stable [06.05.2020]
 * @param {IExtendedFormEntity<TEntity>} wrapper
 * @param {IGenericFieldEntity2} fieldProps
 * @returns {AnyT}
 */
exports.getFormFieldValue = function (wrapper, fieldProps) {
    return type_1.isDef(fieldProps.value)
        ? fieldProps.value
        : getFieldValueByName(wrapper, fieldProps.name);
};
/**
 * @stable [11.05.2020]
 * @param {IExtendedFormEntity<TEntity>} formEntity
 * @param {IFieldProps} fieldProps
 * @param {IFieldProps} defaultFieldProps
 * @returns {AnyT}
 */
var getFormFieldDisplayValue = function (formEntity, fieldProps, defaultFieldProps) {
    return type_1.isDef(fieldProps.displayValue)
        ? fieldProps.displayValue
        : (getFieldValueByName(formEntity, fieldProps.displayName || cond_1.ifNotNilThanValue(defaultFieldProps, function () { return defaultFieldProps.displayName; })));
};
/**
 * @stable [11.05.2020]
 * @param {IExtendedFormEntity<TEntity>} entity
 * @param {IFieldProps} fieldProps
 * @returns {AnyT}
 */
var getFormFieldOriginalValue = function (entity, fieldProps) {
    return type_1.isDef(fieldProps.originalValue)
        ? fieldProps.originalValue
        : (cond_1.ifNotNilThanValue(entity.originalEntity, function (originalEntity) { return cond_1.ifNotEmptyThanValue(fieldProps.name, function (fieldName) { return originalEntity[fieldName]; }, definitions_interface_1.UNDEF_SYMBOL); }, definitions_interface_1.UNDEF_SYMBOL));
};
/**
 * @stable [23.03.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isFormDisabled = function (entity) {
    return R.isNil(entity) ? false : (wrapper_1.isDisabled(entity) || form_entity_1.FormEntityUtils.inProgress(entity));
};
/**
 * @stable [23.04.2020]
 * @param {IFormProps<TEntity>} entity
 * @returns {boolean}
 */
exports.isFormDirty = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return (wrapper_1.isAlwaysDirty(entity) || cond_1.ifNotNilThanValue(select_1.selectForm(entity), function (form) { return wrapper_1.isDirty(form); }, false)); }, false);
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} formEntity
 * @param {IGenericFieldEntity2} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldReadOnly = function (formEntity, fieldProps) {
    return nvl_1.nvl(cond_1.ifNotNilThanValue(fieldProps, function () { return fieldProps.readOnly; }), cond_1.ifNotNilThanValue(formEntity, function () { return formEntity.readOnly; })) === true;
};
/**
 * @stable [23.03.2020]
 * @param {IFormProps} formProps
 * @param {IGenericFieldEntity2} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldDisabled = function (formProps, fieldProps) {
    return R.isNil(fieldProps.disabled) ? exports.isFormDisabled(formProps) : wrapper_1.isDisabled(fieldProps);
};
/**
 * @stable [23.03.2020]
 * @param {IFormProps} formProps
 * @param {IGenericFieldEntity2} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldChangeable = function (formProps, fieldProps) {
    return R.isNil(fieldProps.changeable) ? wrapper_1.isChangeable(formProps) : wrapper_1.isChangeable(fieldProps);
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} formProps
 * @returns {boolean}
 */
exports.isFormSubmittable = function (formProps) {
    return isFormValid(formProps)
        && exports.isFormDirty(formProps)
        && !exports.isFormDisabled(formProps);
};
/**
 * @stable [23.03.2020]
 * @param {IFormProps<TEntity extends IEntity>} formProps
 * @returns {boolean}
 */
exports.isFormResettable = function (formProps) {
    return wrapper_1.isAlwaysResettable(formProps)
        || (exports.isFormDirty(formProps)
            && !exports.isFormDisabled(formProps));
};
/**
 * @stable [23.03.2020]
 * @param {IFormProps<TEntity extends IEntity>} formProps
 * @param {ITabProps} tab
 * @returns {boolean}
 */
exports.isFormTabActive = function (formProps, tab) {
    return tab_1.TabUtils.isActive(select_1.selectForm(formProps), tab);
};
/**
 * @stable [11.05.2020]
 */
var FormUtils = /** @class */ (function () {
    function FormUtils() {
    }
    FormUtils.fieldDisplayValue = getFormFieldDisplayValue; /* @stable [11.05.2020] */
    FormUtils.fieldOriginalValue = getFormFieldOriginalValue; /* @stable [11.05.2020] */
    FormUtils.inProgress = form_entity_1.FormEntityUtils.inProgress; /* @stable [11.05.2020] */
    FormUtils.isChanged = form_entity_1.FormEntityUtils.isChanged; /* @stable [11.05.2020] */
    FormUtils.isTouched = form_entity_1.FormEntityUtils.isTouched; /* @stable [11.05.2020] */
    FormUtils.isValid = isFormValid; /* @stable [11.05.2020] */
    return FormUtils;
}());
exports.FormUtils = FormUtils;
//# sourceMappingURL=form.js.map