"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var mapper_generic_1 = require("./mapper-generic");
var definition_1 = require("../definition");
var select_1 = require("./select");
/**
 * @component-props-mapper
 * @stable [19.05.2020]
 *
 * @param {IFieldsContainer} container
 * @returns {IGenericBaseSelectEntity}
 */
var mapPlaceFieldProps = function (container) { return (__assign({ dictionary: definition_1.DictionariesEnum.PLACES }, mapper_generic_1.GenericMappers.dictionaryEntityAsSelectEntity(container.props.dictionaries.places), { onDictionaryFilterChange: container.dictionaryStoreProxy.dispatchLoadDictionary })); };
/**
 * @component-props-mapper
 * @stable [09.05.2020]
 *
 * @param {IFormProps<TEntity>} props
 * @returns {IFormProps<TEntity>}
 */
var mapFormProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.extendedEntity(props), mapper_generic_1.GenericMappers.formEntity(props)));
};
var mapPageToolbarProps = function (props) {
    return mapper_generic_1.GenericMappers.paginatedLifeCycleEntity(props);
};
var mapSearchToolbarProps = function (props) {
    return mapper_generic_1.GenericMappers.activeQueryEntity(props);
};
var mapPageToolbarContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), mapper_generic_1.GenericMappers.listEntity(props)));
};
/**
 * @container-props-mapper
 * @stable [09.05.2020]
 *
 * @param {IFormContainerProps} props
 * @returns {IFormContainerProps}
 */
var mapFormContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.extendedEntity(props), mapper_generic_1.GenericMappers.formEntity(props), mapper_generic_1.GenericMappers.sectionNameWrapper(props)));
};
/**
 * @container-props-mapper
 * @stable [10.05.2020]
 *
 * @param {IListContainerProps} props
 * @returns {IListContainerProps}
 */
var mapListContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.listEntity(props), mapper_generic_1.GenericMappers.sectionNameWrapper(props)));
};
/**
 * @container-props-mapper
 * @stable [10.05.2020]
 *
 * @param {IFormContainerProps & IPrimaryFilterExtendedFormEntity} props
 * @returns {IFormContainerProps}
 */
var mapFormPrimaryFilterContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), select_1.Selectors.primaryFilter(props)));
};
/**
 * @container-props-mapper
 * @stable [10.05.2020]
 *
 * @param {IFilterFormDialogContainerProps} props
 * @returns {IFilterFormDialogContainerProps}
 */
var mapFilterFormDialogContainerProps = function (props) {
    return mapFormContainerProps(props);
};
/**
 * @container-props-mapper
 * @stable [10.05.2020]
 *
 * @param {IFilterFormDialogContainerProps & ISecondaryFilterExtendedFormEntity} props
 * @returns {IFilterFormDialogContainerProps}
 */
var mapFilterFormDialogSecondaryFilterContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), select_1.Selectors.secondaryFilter(props)));
};
/**
 * @container-props-mapper
 * @stable [09.05.2020]
 *
 * @param {IToolbarToolsContainerProps} props
 * @returns {IToolbarToolsContainerProps}
 */
var mapToolbarToolsContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), { toolbarTools: __assign({}, mapper_generic_1.GenericMappers.listEntityAsDisabled(props), { activeTools: select_1.Selectors.activeToolbarToolsFromDirtyWrapper(select_1.Selectors.form(props)) || [] }) }));
};
/**
 * @container-props-mapper
 * @stable [10.05.2020]
 *
 * @param {IToolbarToolsContainerProps & ISecondaryFilterFormEntity} props
 * @returns {IToolbarToolsContainerProps}
 */
var mapToolbarToolsSecondaryFilterContainerProps = function (props) {
    return mapToolbarToolsContainerProps(__assign({}, asToolbarToolsContainerProps(props), mapper_generic_1.GenericMappers.secondaryFilterFormEntityAsFormEntity(props)));
};
/**
 * @container-props-as
 * @stable [09.05.2020]
 *
 * @param {TProps} props
 * @returns {IToolbarToolsContainerProps}
 */
var asToolbarToolsContainerProps = function (props) { return props; };
var mapSearchToolbarContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), mapper_generic_1.GenericMappers.queryFilterEntity(props), mapper_generic_1.GenericMappers.listEntity(props)));
};
var mapSearchToolbarContainerPropsAsSearchToolbarProps = function (props) {
    return (__assign({}, mapSearchToolbarProps(select_1.Selectors.queryFilter(props)), mapper_generic_1.GenericMappers.listEntityAsDisabled(props), props.toolbarConfiguration));
};
var mapPageToolbarContainerPropsAsPageToolbarProps = function (props) {
    return (__assign({}, mapPageToolbarProps(select_1.Selectors.list(props)), props.toolbarConfiguration));
};
/**
 * @container-component-props-mapper
 * @stable [09.05.2020]
 * @param {IFormContainerProps} props
 * @returns {IFormProps}
 */
var mapFormContainerPropsAsFormProps = function (props) {
    return (__assign({}, mapFormProps(props), props.formConfiguration));
};
/**
 * @container-component-props-mapper
 * @stable [10.05.2020]
 * @param {IToolbarToolsContainerProps} props
 * @returns {IToolbarToolsProps}
 */
var mapToolbarToolsContainerPropsAsToolbarTools = function (props) {
    return (__assign({}, props.toolbarTools, props.toolbarToolsConfiguration));
};
/**
 * @stable [06.05.2020]
 */
var ComponentMappers = /** @class */ (function () {
    function ComponentMappers() {
    }
    ComponentMappers.filterFormDialogContainerProps = mapFilterFormDialogContainerProps; /* @stable [10.05.2020] */
    ComponentMappers.filterFormDialogSecondaryFilterContainerProps = mapFilterFormDialogSecondaryFilterContainerProps; /* @stable [10.05.2020] */
    ComponentMappers.formContainerProps = mapFormContainerProps; /* @stable [10.05.2020] */
    ComponentMappers.formContainerPropsAsFormProps = mapFormContainerPropsAsFormProps; /* @stable [10.05.2020] */
    ComponentMappers.formPrimaryFilterContainerProps = mapFormPrimaryFilterContainerProps; /* @stable [10.05.2020] */
    ComponentMappers.listContainerProps = mapListContainerProps; /* @stable [10.05.2020] */
    ComponentMappers.pageToolbarContainerProps = mapPageToolbarContainerProps;
    ComponentMappers.pageToolbarContainerPropsAsPageToolbarProps = mapPageToolbarContainerPropsAsPageToolbarProps;
    ComponentMappers.pageToolbarProps = mapPageToolbarProps;
    ComponentMappers.placeFieldProps = mapPlaceFieldProps; /* @stable [19.05.2020] */
    ComponentMappers.searchToolbarContainerProps = mapSearchToolbarContainerProps;
    ComponentMappers.searchToolbarContainerPropsAsSearchToolbarProps = mapSearchToolbarContainerPropsAsSearchToolbarProps;
    ComponentMappers.searchToolbarProps = mapSearchToolbarProps;
    ComponentMappers.toolbarToolsContainerProps = mapToolbarToolsContainerProps; /* @stable [09.05.2020] */
    ComponentMappers.toolbarToolsContainerPropsAsToolbarTools = mapToolbarToolsContainerPropsAsToolbarTools; /* @stable [10.05.2020] */
    ComponentMappers.toolbarToolsSecondaryFilterContainerProps = mapToolbarToolsSecondaryFilterContainerProps; /* @stable [10.05.2020] */
    return ComponentMappers;
}());
exports.ComponentMappers = ComponentMappers;
//# sourceMappingURL=mapper-component.js.map