"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var filter_1 = require("./filter");
var cond_1 = require("./cond");
var definition_1 = require("../definition");
var select_1 = require("./select");
var wrapper_1 = require("./wrapper");
var entity_1 = require("./entity");
var nvl_1 = require("./nvl");
var type_1 = require("./type");
/**
 * @stable [19.05.2020]
 * @param {TValue} options
 * @returns {IOptionsWrapper<TValue>}
 */
var mapOptions = function (options) {
    return filter_1.defValuesFilter({ options: options });
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {TValue} layout
 * @returns {ILayoutWrapper<TValue>}
 */
var mapLayout = function (layout) {
    return filter_1.defValuesFilter({ layout: layout });
};
/**
 * @stable [19.05.2020]
 * @param {boolean} waitingForOptions
 * @returns {IWaitingForOptionsWrapper}
 */
exports.mapWaitingForOptions = function (waitingForOptions) {
    return filter_1.defValuesFilter({ waitingForOptions: waitingForOptions });
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {TForm} form
 * @returns {IFormWrapper<TForm>}
 */
var mapForm = function (form) {
    return filter_1.defValuesFilter({ form: form });
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {boolean} disabled
 * @returns {IDisabledWrapper}
 */
var mapDisabled = function (disabled) {
    return filter_1.defValuesFilter({ disabled: disabled });
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IProgressWrapper} entity
 * @returns {IDisabledWrapper}
 */
var mapProgressAsDisabled = function (entity) { return mapDisabled(wrapper_1.WrapperUtils.inProgress(entity)); };
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {string} sectionName
 * @returns {ISectionNameWrapper}
 */
var mapSectionName = function (sectionName) {
    return filter_1.defValuesFilter({ sectionName: sectionName });
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {ISectionNameWrapper} wrapper
 * @returns {ISectionNameWrapper}
 */
var mapSectionNameWrapper = function (wrapper) {
    return mapSectionName(select_1.Selectors.sectionName(wrapper));
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {TList} list
 * @returns {IListWrapper<TList>}
 */
var mapList = function (list) {
    return filter_1.defValuesFilter({ list: list });
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IListEntity} entity
 * @returns {IListEntity}
 */
var mapListEntity = function (entity) { return mapList(select_1.Selectors.list(entity)); };
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IListEntity} listEntity
 * @returns {IDisabledWrapper}
 */
var mapListEntityAsDisabled = function (listEntity) {
    return mapProgressAsDisabled(select_1.Selectors.list(listEntity));
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {TEntity} queryFilter
 * @returns {IQueryFilterWrapper<TEntity>}
 */
var mapQueryFilter = function (queryFilter) {
    return filter_1.defValuesFilter({ queryFilter: queryFilter });
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {TEntity} primaryFilter
 * @returns {IPrimaryFilterWrapper<TEntity>}
 */
var mapPrimaryFilter = function (primaryFilter) {
    return filter_1.defValuesFilter({ primaryFilter: primaryFilter });
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {TEntity} secondaryFilter
 * @returns {ISecondaryFilterWrapper<TEntity>}
 */
var mapSecondaryFilter = function (secondaryFilter) {
    return filter_1.defValuesFilter({ secondaryFilter: secondaryFilter });
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {string} query
 * @returns {IQueryWrapper}
 */
var mapQuery = function (query) { return filter_1.defValuesFilter({ query: query }); };
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IQueryFilterEntity} entity
 * @returns {IQueryFilterEntity}
 */
var mapQueryFilterEntity = function (entity) {
    return mapQueryFilter(select_1.Selectors.queryFilter(entity));
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IFormEntity<TEntity>} entity
 * @returns {IFormEntity<TEntity>}
 */
var mapFormEntity = function (entity) {
    return mapForm(select_1.Selectors.form(entity));
};
/**
 * @mapper
 * @stable [09.05.2020]
 * @param {ISecondaryFilterFormEntity<TEntity>} entity
 * @returns {IFormEntity<TEntity>}
 */
var mapSecondaryFilterFormEntityAsFormEntity = function (entity) {
    return mapFormEntity(select_1.Selectors.secondaryFilter(entity));
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IQueryFilterEntity} entity
 * @returns {IQueryWrapper}
 */
var mapQueryFilterEntityAsQuery = function (entity) {
    return mapQuery(select_1.Selectors.queryFilterEntityQuery(entity));
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IReduxPagedEntity} entity
 * @returns {IReduxPagedEntity}
 */
var mapPagedEntity = function (entity) { return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    page: entity.page,
    pageSize: entity.pageSize,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IExtendedEntity<TEntity>} extendedEntity
 * @returns {IExtendedEntity<TEntity>}
 */
var mapExtendedEntity = function (extendedEntity) {
    return filter_1.defValuesFilter({
        changes: extendedEntity.changes,
        entity: extendedEntity.entity,
        entityId: extendedEntity.entityId,
        newEntity: extendedEntity.newEntity,
        originalEntity: extendedEntity.originalEntity,
    });
};
/**
 * @stable [19.05.2020]
 * @param {ISelectOptionEntity<TRawData>} entity
 * @returns {ISelectOptionEntity<TRawData>}
 */
var mapSelectOptionEntity = function (entity) {
    return filter_1.defValuesFilter({
        disabled: entity.disabled,
        label: entity.label,
        rawData: entity.rawData,
        value: entity.value,
    });
};
/**
 * @stable [19.05.2020]
 * @param {TEntity} entity
 * @returns {ISelectOptionEntity<TEntity extends IOptionEntity>}
 */
var mapOptionEntityAsSelectOptionEntity = function (entity) {
    return mapSelectOptionEntity({
        value: entity.id,
        label: entity.name,
        disabled: entity.disabled,
        rawData: entity,
    });
};
/**
 * @stable [19.05.2020]
 * @param {TEntity[] | TEntity} data
 * @returns {Array<ISelectOptionEntity<TEntity extends IOptionEntity>>}
 */
var mapOptionEntitiesAsSelectOptionEntities = function (data) {
    return cond_1.ConditionUtils.ifNotNilThanValue(data, function () { return [].concat(data).map(function (entity) { return mapOptionEntityAsSelectOptionEntity(entity); }); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IReduxFormEntity<TEntity extends IEntity>} formEntity
 * @param {TEntity} entity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
var mapEntityAsExtendedEntity = function (formEntity, entity) {
    var newEntity = entity_1.isNewEntity(entity);
    var _a = formEntity || {}, changes = _a.changes, defaultChanges = _a.defaultChanges;
    var originalEntity;
    if (!R.isNil(nvl_1.nvl(defaultChanges, entity))) {
        originalEntity = __assign({}, defaultChanges, entity);
    }
    return mapExtendedEntity({
        changes: changes,
        entity: __assign({}, originalEntity, changes),
        entityId: cond_1.orUndef(!newEntity, function () { return entity.id; }),
        newEntity: newEntity,
        originalEntity: originalEntity,
    });
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IReduxFormEntity<TEntity>} formEntity
 * @param {TEntity} entity
 * @returns {IExtendedFormEntity<TEntity>}
 */
var mapEntityAsExtendedFormEntity = function (formEntity, entity) {
    return (__assign({}, mapForm(formEntity), mapEntityAsExtendedEntity(formEntity, entity)));
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IReduxFormEntity<TEntity>} formEntity
 * @param {TEntity} entity
 * @returns {TEntity}
 */
var mapExtendedFormEntityAsFinalEntity = function (formEntity, entity) {
    return mapEntityAsExtendedFormEntity(formEntity, entity).entity;
};
/**
 * @mapper
 * @stable [09.05.2020]
 * @param {IListEntity<TEntity>} listEntity
 * @param {IReduxFormEntity<TEntity>} formEntity
 * @returns {IExtendedFormEntity<TEntity>}
 */
var mapListSelectedEntityAsExtendedFormEntity = function (listEntity, formEntity) {
    return mapEntityAsExtendedFormEntity(formEntity, select_1.Selectors.listSelectedEntity(listEntity));
};
/**
 * @stable [10.05.2020]
 * @param {IListEntity<TEntity>} listEntity
 * @param {IReduxFormEntity<TEntity>} formEntity
 * @returns {TEntity}
 */
var mapListSelectedExtendedFormEntityAsFinalEntity = function (listEntity, formEntity) {
    return mapListSelectedEntityAsExtendedFormEntity(listEntity, formEntity).entity;
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IReduxActiveQueryEntity} entity
 * @returns {IReduxActiveQueryEntity}
 */
var mapActiveQueryEntity = function (entity) { return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    active: entity.active,
    query: entity.query,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IReduxLifeCycleEntity} entity
 * @returns {IReduxLifeCycleEntity}
 */
var mapLifeCycleEntity = function (entity) { return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    error: entity.error,
    progress: entity.progress,
    touched: entity.touched,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IReduxPaginatedEntity} entity
 * @returns {IReduxPaginatedEntity}
 */
var mapPaginatedEntity = function (entity) {
    return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter(__assign({}, mapPagedEntity(entity), { lockPage: entity.lockPage, totalAmount: entity.totalAmount, totalCount: entity.totalCount })); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @mapper
 * @stable [09.05.2020]
 * @param {IReduxPaginatedEntity} entity
 * @param {number} pageSize
 * @returns {IReduxPagedEntity}
 */
var mapPaginatedEntityAsPagedEntity = function (entity, pageSize) {
    if (pageSize === void 0) { pageSize = definition_1.DEFAULT_PAGE_SIZE; }
    return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return mapPagedEntity({
        page: entity.lockPage ? entity.page : definition_1.FIRST_PAGE,
        pageSize: pageSize,
    }); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @mapper
 * @stable [09.05.2020]
 * @param {IListEntity} entity
 * @param {number} pageSize
 * @returns {IReduxPagedEntity}
 */
var mapListEntityAsPagedEntity = function (entity, pageSize) {
    if (pageSize === void 0) { pageSize = definition_1.DEFAULT_PAGE_SIZE; }
    return mapPaginatedEntityAsPagedEntity(select_1.Selectors.list(entity), pageSize);
};
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IReduxPaginatedLifeCycleEntity} entity
 * @returns {IReduxPaginatedLifeCycleEntity}
 */
var mapPaginatedLifeCycleEntity = function (entity) { return (__assign({}, mapLifeCycleEntity(entity), mapPaginatedEntity(entity))); };
/**
 * @mapper
 * @stable [08.05.2020]
 * @param {IReduxHolderLayoutEntity} wrapper
 * @returns {IReduxHolderLayoutEntity}
 */
var mapLayoutEntity = function (wrapper) { return mapLayout(select_1.Selectors.layout(wrapper)); };
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IPrimaryFilterReduxFormEntity<TEntity>} formEntity
 * @param {TEntity} entity
 * @returns {TEntity}
 */
var mapPrimaryFilterEntityAsFinalEntity = function (formEntity, entity) {
    return mapExtendedFormEntityAsFinalEntity(select_1.Selectors.primaryFilter(formEntity), entity);
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {ISecondaryFilterReduxFormEntity<TEntity>} formEntity
 * @param {TEntity} entity
 * @returns {TEntity}
 */
var mapSecondaryFilterEntityAsFinalEntity = function (formEntity, entity) {
    return mapExtendedFormEntityAsFinalEntity(select_1.Selectors.secondaryFilter(formEntity), entity);
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IReduxFormEntity<TEntity>} reduxFormEntity
 * @param {TEntity} entity
 * @returns {IPrimaryFilterExtendedFormEntity<TEntity>}
 */
var mapEntityAsPrimaryFilterExtendedFormEntity = function (reduxFormEntity, entity) {
    return mapPrimaryFilter(mapEntityAsExtendedFormEntity(reduxFormEntity, entity));
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IPrimaryFilterReduxFormEntity<TEntity>} wrapper
 * @param {TEntity} entity
 * @returns {IPrimaryFilterExtendedFormEntity<TEntity>}
 */
var mapPrimaryFilterEntityAsPrimaryFilterExtendedFormEntity = function (wrapper, entity) {
    return mapEntityAsPrimaryFilterExtendedFormEntity(select_1.Selectors.primaryFilter(wrapper), entity);
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IReduxFormEntity<TEntity>} reduxFormEntity
 * @param {TEntity} entity
 * @returns {ISecondaryFilterExtendedFormEntity<TEntity>}
 */
var mapEntityAsSecondaryFilterExtendedFormEntity = function (reduxFormEntity, entity) {
    return mapSecondaryFilter(mapEntityAsExtendedFormEntity(reduxFormEntity, entity));
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {ISecondaryFilterReduxFormEntity<TEntity>} wrapper
 * @param {TEntity} entity
 * @returns {ISecondaryFilterExtendedFormEntity<TEntity>}
 */
var mapSecondaryFilterEntityAsSecondaryFilterExtendedFormEntity = function (wrapper, entity) {
    return mapEntityAsSecondaryFilterExtendedFormEntity(select_1.Selectors.secondaryFilter(wrapper), entity);
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IQueryFilterEntity & IListEntity<TEntity>} wrapper
 * @returns {TFilter}
 */
var mapFullSearchFilter = function (wrapper) { return (__assign({}, mapQueryFilterEntityAsQuery(wrapper), mapListEntityAsPagedEntity(wrapper), mapPrimaryFilterEntityAsFinalEntity(wrapper), mapSecondaryFilterEntityAsFinalEntity(wrapper))); };
/**
 * @stable [19.05.2020]
 * @param {IReduxDictionaryEntity<TEntity>} dictionaryEntity
 * @param {(data: (TEntity[] | TEntity)) => AnyT} accessor
 * @returns {Array<ISelectOptionEntity<TEntity>>}
 */
var mapDictionaryEntityAsSelectOptionEntities = function (dictionaryEntity, accessor) {
    return GenericMappers.optionEntitiesAsSelectOptionEntities(cond_1.ConditionUtils.ifNotNilThanValue(select_1.Selectors.data(dictionaryEntity), function (data) { return type_1.TypeUtils.isFn(accessor) ? accessor(data) : data; }));
};
/**
 * @stable [19.05.2020]
 * @param {IReduxDictionaryEntity<TEntity>} entity
 * @param {(data: TEntity[]) => TResult} accessor
 * @returns {IReduxBaseSelectEntity}
 */
var mapDictionaryEntityAsSelectEntity = function (entity, accessor) {
    return (__assign({}, exports.mapWaitingForOptions(wrapper_1.WrapperUtils.isLoading(entity)), mapOptions(mapDictionaryEntityAsSelectOptionEntities(entity, accessor))));
};
/**
 * @stable [06.05.2020]
 */
var GenericMappers = /** @class */ (function () {
    function GenericMappers() {
    }
    GenericMappers.activeQueryEntity = mapActiveQueryEntity; /* stable [07.05.2020] */
    GenericMappers.dictionaryEntityAsSelectEntity = mapDictionaryEntityAsSelectEntity; /* stable [19.05.2020] */
    GenericMappers.dictionaryEntityAsSelectOptionEntities = mapDictionaryEntityAsSelectOptionEntities; /* stable [19.05.2020] */
    GenericMappers.disabled = mapDisabled; /* stable [07.05.2020] */
    GenericMappers.entityAsExtendedEntity = mapEntityAsExtendedEntity; /* stable [08.05.2020] */
    GenericMappers.entityAsExtendedFormEntity = mapEntityAsExtendedFormEntity; /* stable [10.05.2020] */
    GenericMappers.extendedEntity = mapExtendedEntity; /* stable [08.05.2020] */
    GenericMappers.form = mapForm; /* stable [08.05.2020] */
    GenericMappers.formEntity = mapFormEntity; /* stable [08.05.2020] */
    GenericMappers.fullSearchFilter = mapFullSearchFilter; /* stable [10.05.2020] */
    GenericMappers.layoutEntity = mapLayoutEntity; /* stable [08.05.2020] */
    GenericMappers.listEntity = mapListEntity; /* stable [07.05.2020] */
    GenericMappers.listEntityAsDisabled = mapListEntityAsDisabled; /* stable [08.05.2020] */
    GenericMappers.listEntityAsPagedEntity = mapListEntityAsPagedEntity; /* stable [09.05.2020] */
    GenericMappers.listSelectedEntityAsExtendedFormEntity = mapListSelectedEntityAsExtendedFormEntity; /* stable [09.05.2020] */
    GenericMappers.listSelectedExtendedFormEntityAsFinalEntity = mapListSelectedExtendedFormEntityAsFinalEntity; /* stable [10.05.2020] */
    GenericMappers.optionEntitiesAsSelectOptionEntities = mapOptionEntitiesAsSelectOptionEntities; /* stable [19.05.2020] */
    GenericMappers.options = mapOptions; /* stable [19.05.2020] */
    GenericMappers.pagedEntity = mapPagedEntity; /* stable [07.05.2020] */
    GenericMappers.paginatedEntity = mapPaginatedEntity; /* stable [07.05.2020] */
    GenericMappers.paginatedLifeCycleEntity = mapPaginatedLifeCycleEntity; /* stable [07.05.2020] */
    GenericMappers.primaryFilterEntityAsPrimaryFilterExtendedFormEntity = mapPrimaryFilterEntityAsPrimaryFilterExtendedFormEntity; /* stable [10.05.2020] */
    GenericMappers.query = mapQuery; /* stable [08.05.2020] */
    GenericMappers.queryFilter = mapQueryFilter; /* stable [08.05.2020] */
    GenericMappers.queryFilterEntity = mapQueryFilterEntity; /* stable [07.05.2020] */
    GenericMappers.queryFilterEntityAsQuery = mapQueryFilterEntityAsQuery; /* stable [07.05.2020] */
    GenericMappers.secondaryFilterEntityAsSecondaryFilterExtendedFormEntity = mapSecondaryFilterEntityAsSecondaryFilterExtendedFormEntity; /* stable [10.05.2020] */
    GenericMappers.secondaryFilterFormEntityAsFormEntity = mapSecondaryFilterFormEntityAsFormEntity; /* stable [09.05.2020] */
    GenericMappers.sectionName = mapSectionName; /* stable [08.05.2020] */
    GenericMappers.sectionNameWrapper = mapSectionNameWrapper; /* stable [08.05.2020] */
    GenericMappers.waitingForOptions = exports.mapWaitingForOptions; /* stable [19.05.2020] */
    return GenericMappers;
}());
exports.GenericMappers = GenericMappers;
//# sourceMappingURL=mapper-generic.js.map