import { IEffectsAction } from 'redux-effects-promise';
import { IApiEntity, IChannelWrapperEntity, IDictionariesEntity, IExtendedEntity, IExtendedFormEntity, IExtendedLabeledValueEntity, IFormEntity, IFormTabPanelContainerProps, IGenericChannelEntity, IGenericContainer, IGenericNotificationEntity, IReduxStackEntity, IGenericStoreEntity, IGenericTabPanelEntity, IHeaderProps, INamedEntity, INotificationWrapperEntity, IOperationEntity, IPresetsSelectableHoveredEntity, IReduxDictionariesEntity, IReduxFormEntity, IReduxSortDirectionsEntity, ISortDirectionEntity, ISortDirectionsEntity, IReduxHolderStackEntity, ITabPanelEntity, ITransportEntity, ITransportWrapperEntity, IUniversalApplicationEntity, IUnsavedFormChangesDialogContainerProps, IReduxUserEntity, IReduxHolderUserEntity } from '../definition';
import { IActiveValueWrapper, IChannelWrapper, IDictionariesWrapper, IEntity, IEntityIdTWrapper, IErrorWrapper, INotificationWrapper, IStackWrapper, ITransportWrapper, IUserWrapper } from '../definitions.interface';
/**
 * @stable [17.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string}
 */
export declare const selectTransportWrapperToken: (entity: ITransportWrapperEntity<ITransportEntity>) => string;
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string[]}
 */
export declare const selectTransportWrapperQueue: (entity: ITransportWrapperEntity<ITransportEntity>) => string[];
/**
 * @stable [13.02.2020]
 * @param {TErrorWrapper} entity
 * @returns {TResult}
 */
export declare const selectError: <TResult = any, TErrorWrapper extends IErrorWrapper<TResult> = IErrorWrapper<TResult>>(entity: TErrorWrapper) => TResult;
/**
 * @stable [13.02.2020]
 * @param {IEffectsAction} action
 * @returns {TResult}
 */
export declare const selectErrorFromAction: <TResult = any>(action: IEffectsAction) => TResult;
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
export declare const mapEntityId: (id: string | number) => IEntityIdTWrapper;
/**
 * @stable [13.11.2019]
 * @param {IReduxSortDirectionsEntity} directions
 * @returns {ISortDirectionsEntity}
 */
export declare const mapSortDirectionsWrapperEntity: (directions: IReduxSortDirectionsEntity) => ISortDirectionsEntity;
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
export declare const mapIdentifiedEntity: (entity: IEntityIdTWrapper) => IEntityIdTWrapper;
/**
 * @stable [10.02.2020]
 * @param {IGenericTabPanelEntity} tabPanel
 * @returns {ITabPanelEntity}
 */
export declare const mapTabPanelEntity: (tabPanel: IGenericTabPanelEntity) => ITabPanelEntity;
/**
 * @stable [21.11.2019]
 * @param {ITabPanelEntity} tabPanelWrapperEntity
 * @returns {ITabPanelEntity}
 */
export declare const mapTabPanelWrapperEntity: (tabPanelWrapperEntity: ITabPanelEntity) => ITabPanelEntity;
/**
 * @stable [30.03.2020]
 * @param {TUser} user
 * @returns {IUserWrapper<TUser>}
 */
export declare const mapUser: <TUser = IReduxUserEntity>(user: TUser) => IUserWrapper<TUser>;
/**
 * @stable [14.04.2020]
 * @param {TValue} stack
 * @returns {IStackWrapper<TValue>}
 */
export declare const mapStack: <TValue>(stack: TValue) => IStackWrapper<TValue>;
/**
 * @stable [14.04.2020]
 * @param {TValue} notification
 * @returns {INotificationWrapper<TValue>}
 */
export declare const mapNotification: <TValue>(notification: TValue) => INotificationWrapper<TValue>;
/**
 * @stable [14.04.2020]
 * @param {TValue} channel
 * @returns {IChannelWrapper<TValue>}
 */
export declare const mapChannel: <TValue>(channel: TValue) => IChannelWrapper<TValue>;
/**
 * @stable [14.04.2020]
 * @param {TValue} transport
 * @returns {ITransportWrapper<TValue>}
 */
export declare const mapTransport: <TValue>(transport: TValue) => ITransportWrapper<TValue>;
/**
 * @stable [14.04.2020]
 * @param {TValue} dictionaries
 * @returns {IDictionariesWrapper<TValue>}
 */
export declare const mapDictionaries: <TValue>(dictionaries: TValue) => IDictionariesWrapper<TValue>;
/**
 * @stable [12.04.2020]
 * @param {TActiveValue} activeValue
 * @returns {IActiveValueWrapper<TActiveValue>}
 */
export declare const mapActiveValue: <TActiveValue>(activeValue: TActiveValue) => IActiveValueWrapper<TActiveValue>;
/**
 * TODO
 * @deprecated Use mapForm
 */
export declare const mapEditableEntity: <TEntity extends IEntity = IEntity>(form: IReduxFormEntity<TEntity>) => IExtendedFormEntity<TEntity>;
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
export declare const mapSortDirectionEntity: (entity: ISortDirectionEntity) => ISortDirectionEntity;
/**
 * @stable [30.03.2020]
 * @param {IReduxHolderUserEntity<TEntity>} wrapper
 * @returns {IReduxHolderUserEntity<TEntity>}
 */
export declare const mapUserWrapperEntity: <TEntity = IReduxUserEntity>(wrapper: IReduxHolderUserEntity<TEntity>) => IReduxHolderUserEntity<TEntity>;
/**
 * @stable [30.03.2020]
 * @param {IReduxHolderStackEntity<TEntity>} wrapper
 * @returns {IReduxHolderStackEntity<TEntity>}
 */
export declare const mapStackWrapperEntity: <TEntity = IReduxStackEntity>(wrapper: IReduxHolderStackEntity<TEntity>) => IReduxHolderStackEntity<TEntity>;
/**
 * @stable [14.04.2020]
 * @param {INotificationWrapperEntity<TEntity>} wrapper
 * @returns {INotificationWrapperEntity<TEntity>}
 */
export declare const mapNotificationWrapperEntity: <TEntity = IGenericNotificationEntity>(wrapper: INotificationWrapperEntity<TEntity>) => INotificationWrapperEntity<TEntity>;
/**
 * @stable [14.04.2020]
 * @param {IChannelWrapperEntity<TEntity>} wrapper
 * @returns {IChannelWrapperEntity<TEntity>}
 */
export declare const mapChannelWrapperEntity: <TEntity = IGenericChannelEntity>(wrapper: IChannelWrapperEntity<TEntity>) => IChannelWrapperEntity<TEntity>;
/**
 * @stable [28.03.2020]
 * @param {ITransportWrapperEntity<TTransport>} wrapper
 * @returns {ITransportWrapperEntity<TTransport>}
 */
export declare const mapTransportWrapperEntity: <TTransport = ITransportEntity>(wrapper: ITransportWrapperEntity<TTransport>) => ITransportWrapperEntity<TTransport>;
/**
 * @stable [28.03.2020]
 * @param {IDictionariesEntity<TDictionaries>} wrapper
 * @returns {IDictionariesEntity<TDictionaries>}
 */
export declare const mapDictionariesWrapperEntity: <TDictionaries = IReduxDictionariesEntity>(wrapper: IDictionariesEntity<TDictionaries>) => IDictionariesEntity<TDictionaries>;
/**
 * @stable [12.04.2020]
 * @param {IActiveValueWrapper<TValue>} wrapper
 * @returns {IActiveValueWrapper<TValue>}
 */
export declare const mapActiveValueWrapper: <TValue>(wrapper: IActiveValueWrapper<TValue>) => IActiveValueWrapper<TValue>;
/**
 * @deprecated
 */
export declare const mapNewExtendedEntity: <TEntity extends IEntity = IEntity>(editableEntity: IReduxFormEntity<TEntity>) => IExtendedEntity<TEntity>;
/**
 * @stable [23.12.2019]
 * @param {IExtendedEntity<TEntity>} extendedEntity
 * @returns {IApiEntity<TEntity>}
 */
export declare const mapApiEntity: <TEntity = IEntity>(extendedEntity: IExtendedEntity<TEntity>) => IApiEntity<TEntity>;
/**
 * @stable [22.04.2020]
 * @param {INamedEntity} entity
 * @returns {IExtendedLabeledValueEntity}
 */
export declare const mapExtendedLabeledValueEntity: (entity: INamedEntity) => IExtendedLabeledValueEntity<IEntity, string | number>;
/**
 * @stable [25.11.2019]
 * @param {string[]} queue
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
export declare const hasQueueOperations: (queue: string[], ...operations: (string | IOperationEntity)[]) => boolean;
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
export declare const hasTransportWrapperQueueOperations: (entity: ITransportWrapperEntity<ITransportEntity>, ...operations: (string | IOperationEntity)[]) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const isApplicationInProgress: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const doesApplicationErrorExist: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const isApplicationMessageVisible: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [14.04.2020]
 * @param {IGenericStoreEntity<TDictionaries>} entity
 * @returns {IGenericStoreEntity<TDictionaries>}
 */
export declare const mapStoreEntity: <TDictionaries = {}>(entity: IGenericStoreEntity<TDictionaries>) => IGenericStoreEntity<TDictionaries>;
/**
 * @container-props-mapper
 * @stable [13.04.2020]
 *
 * @param {IFormTabPanelContainerProps} props
 * @returns {IFormTabPanelContainerProps}
 */
export declare const mapFormTabPanelContainerProps: (props: IFormTabPanelContainerProps<IEntity>) => IFormTabPanelContainerProps<IEntity>;
/**
 * @container-props-mapper
 * @stable [23.04.2020]
 *
 * @param {IFormEntity<TEntity>} props
 * @param {IGenericContainer} proxyContainer
 * @returns {IUnsavedFormChangesDialogContainerProps}
 */
export declare const mapUnsavedFormChangesDialogContainerProps: <TEntity = IEntity>(props: IFormEntity<TEntity>, proxyContainer: IGenericContainer<import("core/definition/generic-container-definition.interface").IGenericContainerProps<{}>, {}>) => IUnsavedFormChangesDialogContainerProps;
/**
 * @stable [05.05.2020]
 */
export declare class Mappers {
    static readonly dictionaryEntityAsSelectEntity: <TEntity, TResult = TEntity[]>(entity: import("core/definition/dictionary-definition.interface").IReduxDictionaryEntity<TEntity>, accessor?: (data: TEntity[]) => TResult) => import("core/definition/select-definition.interface").IReduxBaseSelectEntity;
    static readonly dictionaryEntityAsSelectOptionEntities: <TEntity>(dictionaryEntity: import("core/definition/dictionary-definition.interface").IReduxDictionaryEntity<TEntity>, accessor?: (data: TEntity | TEntity[]) => any) => import("core/definition/select-definition.interface").ISelectOptionEntity<TEntity>[];
    static readonly entityAsExtendedEntity: <TEntity extends IEntity = IEntity>(formEntity: IReduxFormEntity<TEntity>, entity?: TEntity) => IExtendedEntity<TEntity>;
    static readonly entityAsExtendedFormEntity: <TEntity = IEntity>(formEntity: IReduxFormEntity<TEntity>, entity?: TEntity) => IExtendedFormEntity<TEntity>;
    static readonly filterFormDialogContainerProps: (props: import("core/definition/filter-form-dialog-definition.interface").IFilterFormDialogContainerProps) => import("core/definition/filter-form-dialog-definition.interface").IFilterFormDialogContainerProps;
    static readonly filterFormDialogSecondaryFilterContainerProps: (props: import("core/definition/filter-form-dialog-definition.interface").IFilterFormDialogContainerProps & import("core/definition/form-definition.interface").ISecondaryFilterExtendedFormEntity<IEntity>) => import("core/definition/filter-form-dialog-definition.interface").IFilterFormDialogContainerProps;
    static readonly form: <TForm>(form: TForm) => import("core/definitions.interface").IFormWrapper<TForm>;
    static readonly formContainerProps: (props: import("core/definition/form-definition.interface").IFormContainerProps<IEntity, {}>) => import("core/definition/form-definition.interface").IFormContainerProps<IEntity, {}>;
    static readonly formContainerPropsAsFormProps: (props: import("core/definition/form-definition.interface").IFormContainerProps<IEntity, {}>) => import("core/definition/form-definition.interface").IFormProps<IEntity>;
    static readonly formEntity: <TEntity = IEntity>(entity: IFormEntity<TEntity>) => IFormEntity<TEntity>;
    static readonly formPrimaryFilterContainerProps: (props: import("core/definition/form-definition.interface").IFormContainerProps<IEntity, {}> & import("core/definition/form-definition.interface").IPrimaryFilterExtendedFormEntity<IEntity>) => import("core/definition/form-definition.interface").IFormContainerProps<IEntity, {}>;
    static readonly fullSearchFilter: <TFilter, TEntity = IEntity>(wrapper: import("core/definition/query-definition.interface").IQueryFilterEntity & import("core/definition/list-definition.interface").IListEntity<TEntity, any>) => TFilter;
    static readonly headerProps: (props: IHeaderProps) => IHeaderProps;
    static readonly listContainerProps: (props: import("core/definition/list-definition.interface").IListContainerProps) => import("core/definition/list-definition.interface").IListContainerProps;
    static readonly listEntity: (entity: import("core/definition/list-definition.interface").IListEntity<IEntity, any>) => import("core/definition/list-definition.interface").IListEntity<IEntity, any>;
    static readonly listEntityAsDisabled: (listEntity: import("core/definition/list-definition.interface").IListEntity<IEntity, any>) => import("core/definitions.interface").IDisabledWrapper<boolean>;
    static readonly listEntityAsPagedEntity: (entity: import("core/definition/list-definition.interface").IListEntity<IEntity, any>, pageSize?: number) => import("core/definition/page-definition.interface").IReduxPagedEntity;
    static readonly listSelectedEntityAsExtendedFormEntity: <TEntity = IEntity>(listEntity: import("core/definition/list-definition.interface").IListEntity<TEntity, any>, formEntity: IReduxFormEntity<TEntity>) => IExtendedFormEntity<TEntity>;
    static readonly optionEntitiesAsSelectOptionEntities: <TEntity extends import("core/definition/entity-definition.interface").IOptionEntity>(data: TEntity | TEntity[]) => import("core/definition/select-definition.interface").ISelectOptionEntity<TEntity>[];
    static readonly pagedEntity: (entity: import("core/definition/page-definition.interface").IReduxPagedEntity) => import("core/definition/page-definition.interface").IReduxPagedEntity;
    static readonly pageToolbarContainerProps: (props: import("core/definition/toolbar-definition.interface").IPageToolbarContainerProps) => import("core/definition/toolbar-definition.interface").IPageToolbarContainerProps;
    static readonly paginatedEntity: (entity: import("core/definition/page-definition.interface").IReduxPaginatedEntity) => import("core/definition/page-definition.interface").IReduxPaginatedEntity;
    static readonly placeFieldProps: (container: import("core/definition/container-definition.interface").IFieldsContainer) => import("core/definition/select-definition.interface").IGenericBaseSelectEntity;
    static readonly primaryFilterEntityAsPrimaryFilterExtendedFormEntity: <TEntity = IEntity>(wrapper: import("core/definition/form-definition.interface").IPrimaryFilterReduxFormEntity<TEntity>, entity?: TEntity) => import("core/definition/form-definition.interface").IPrimaryFilterExtendedFormEntity<TEntity>;
    static readonly queryFilterEntity: (entity: import("core/definition/query-definition.interface").IQueryFilterEntity) => import("core/definition/query-definition.interface").IQueryFilterEntity;
    static readonly queryFilterEntityAsQuery: (entity: import("core/definition/query-definition.interface").IQueryFilterEntity) => import("core/definitions.interface").IQueryWrapper<string>;
    static readonly searchToolbarContainerProps: (props: import("core/definition/toolbar-definition.interface").ISearchToolbarContainerProps) => import("core/definition/toolbar-definition.interface").ISearchToolbarContainerProps;
    static readonly secondaryFilterEntityAsSecondaryFilterExtendedFormEntity: <TEntity = IEntity>(wrapper: import("core/definition/form-definition.interface").ISecondaryFilterReduxFormEntity<TEntity>, entity?: TEntity) => import("core/definition/form-definition.interface").ISecondaryFilterExtendedFormEntity<TEntity>;
    static readonly sectionNameWrapper: (wrapper: import("core/definitions.interface").ISectionNameWrapper) => import("core/definitions.interface").ISectionNameWrapper;
    static readonly selectableHoveredEntity: (entity: IPresetsSelectableHoveredEntity) => IPresetsSelectableHoveredEntity;
    static readonly selectedExtendedFormEntityAsFinalEntity: <TEntity = IEntity>(listEntity: import("core/definition/list-definition.interface").IListEntity<TEntity, any>, formEntity: IReduxFormEntity<TEntity>) => TEntity;
    static readonly toolbarToolsContainerProps: (props: import("core/definition/toolbar-tools-definition.interface").IToolbarToolsContainerProps<import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps>) => import("core/definition/toolbar-tools-definition.interface").IToolbarToolsContainerProps<import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps>;
    static readonly toolbarToolsContainerPropsAsToolbarTools: (props: import("core/definition/toolbar-tools-definition.interface").IToolbarToolsContainerProps<import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps>) => import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps;
    static readonly toolbarToolsSecondaryFilterContainerProps: (props: import("core/definition/toolbar-tools-definition.interface").IToolbarToolsContainerProps<import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps> & import("core/definition/form-definition.interface").ISecondaryFilterFormEntity<IEntity>) => import("core/definition/toolbar-tools-definition.interface").IToolbarToolsContainerProps<import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps>;
}
