"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var filter_1 = require("./filter");
var definitions_interface_1 = require("../definitions.interface");
var cond_1 = require("./cond");
var type_1 = require("./type");
var wrapper_1 = require("./wrapper");
var select_1 = require("./select");
var mapper_generic_1 = require("./mapper-generic");
var mapper_component_1 = require("./mapper-component");
/**
 * @stable [17.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string}
 */
exports.selectTransportWrapperToken = function (entity) {
    return select_1.selectToken(select_1.selectTransport(entity));
};
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string[]}
 */
exports.selectTransportWrapperQueue = function (entity) {
    return select_1.selectQueue(select_1.selectTransport(entity));
};
/**
 * @stable [13.02.2020]
 * @param {TErrorWrapper} entity
 * @returns {TResult}
 */
exports.selectError = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.error;
};
/**
 * @stable [13.02.2020]
 * @param {IEffectsAction} action
 * @returns {TResult}
 */
exports.selectErrorFromAction = function (action) { return exports.selectError(action); };
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
exports.mapEntityId = function (id) {
    return filter_1.defValuesFilter({ id: id });
};
/**
 * @stable [13.11.2019]
 * @param {IReduxSortDirectionsEntity} directions
 * @returns {ISortDirectionsEntity}
 */
exports.mapSortDirectionsWrapperEntity = function (directions) {
    return filter_1.defValuesFilter({ directions: directions });
};
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
exports.mapIdentifiedEntity = function (entity) {
    return exports.mapEntityId(select_1.selectEntityId(entity));
};
/**
 * @stable [10.02.2020]
 * @param {IGenericTabPanelEntity} tabPanel
 * @returns {ITabPanelEntity}
 */
exports.mapTabPanelEntity = function (tabPanel) {
    return filter_1.defValuesFilter({ tabPanel: tabPanel });
};
/**
 * @stable [21.11.2019]
 * @param {ITabPanelEntity} tabPanelWrapperEntity
 * @returns {ITabPanelEntity}
 */
exports.mapTabPanelWrapperEntity = function (tabPanelWrapperEntity) {
    return exports.mapTabPanelEntity(select_1.Selectors.tabPanel(tabPanelWrapperEntity));
};
/**
 * @stable [30.03.2020]
 * @param {TUser} user
 * @returns {IUserWrapper<TUser>}
 */
exports.mapUser = function (user) {
    return filter_1.defValuesFilter({ user: user });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} stack
 * @returns {IStackWrapper<TValue>}
 */
exports.mapStack = function (stack) {
    return filter_1.defValuesFilter({ stack: stack });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} notification
 * @returns {INotificationWrapper<TValue>}
 */
exports.mapNotification = function (notification) {
    return filter_1.defValuesFilter({ notification: notification });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} channel
 * @returns {IChannelWrapper<TValue>}
 */
exports.mapChannel = function (channel) {
    return filter_1.defValuesFilter({ channel: channel });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} transport
 * @returns {ITransportWrapper<TValue>}
 */
exports.mapTransport = function (transport) {
    return filter_1.defValuesFilter({ transport: transport });
};
/**
 * @stable [14.04.2020]
 * @param {TValue} dictionaries
 * @returns {IDictionariesWrapper<TValue>}
 */
exports.mapDictionaries = function (dictionaries) {
    return filter_1.defValuesFilter({ dictionaries: dictionaries });
};
/**
 * @stable [12.04.2020]
 * @param {TActiveValue} activeValue
 * @returns {IActiveValueWrapper<TActiveValue>}
 */
exports.mapActiveValue = function (activeValue) {
    return filter_1.defValuesFilter({ activeValue: activeValue });
};
/**
 * TODO
 * @deprecated Use mapForm
 */
exports.mapEditableEntity = function (form) {
    return filter_1.defValuesFilter({ form: form });
};
/**
 * @stable [04.05.2020]
 * @mapper
 *
 * @param {IPresetsSelectableHoveredEntity} entity
 * @returns {IPresetsSelectableHoveredEntity}
 */
var mapSelectableHoveredEntity = function (entity) { return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    hovered: entity.hovered,
    selectable: entity.selectable,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
exports.mapSortDirectionEntity = function (entity) { return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    index: entity.index,
    direction: entity.direction,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [30.03.2020]
 * @param {IReduxHolderUserEntity<TEntity>} wrapper
 * @returns {IReduxHolderUserEntity<TEntity>}
 */
exports.mapUserWrapperEntity = function (wrapper) {
    return exports.mapUser(select_1.selectUser(wrapper));
};
/**
 * @stable [30.03.2020]
 * @param {IReduxHolderStackEntity<TEntity>} wrapper
 * @returns {IReduxHolderStackEntity<TEntity>}
 */
exports.mapStackWrapperEntity = function (wrapper) {
    return exports.mapStack(select_1.Selectors.stack(wrapper));
};
/**
 * @stable [14.04.2020]
 * @param {INotificationWrapperEntity<TEntity>} wrapper
 * @returns {INotificationWrapperEntity<TEntity>}
 */
exports.mapNotificationWrapperEntity = function (wrapper) {
    return exports.mapNotification(select_1.selectNotification(wrapper));
};
/**
 * @stable [14.04.2020]
 * @param {IChannelWrapperEntity<TEntity>} wrapper
 * @returns {IChannelWrapperEntity<TEntity>}
 */
exports.mapChannelWrapperEntity = function (wrapper) {
    return exports.mapChannel(select_1.selectChannel(wrapper));
};
/**
 * @stable [28.03.2020]
 * @param {ITransportWrapperEntity<TTransport>} wrapper
 * @returns {ITransportWrapperEntity<TTransport>}
 */
exports.mapTransportWrapperEntity = function (wrapper) {
    return exports.mapTransport(select_1.selectTransport(wrapper));
};
/**
 * @stable [28.03.2020]
 * @param {IDictionariesEntity<TDictionaries>} wrapper
 * @returns {IDictionariesEntity<TDictionaries>}
 */
exports.mapDictionariesWrapperEntity = function (wrapper) {
    return exports.mapDictionaries(select_1.selectDictionaries(wrapper));
};
/**
 * @stable [12.04.2020]
 * @param {IActiveValueWrapper<TValue>} wrapper
 * @returns {IActiveValueWrapper<TValue>}
 */
exports.mapActiveValueWrapper = function (wrapper) {
    return exports.mapActiveValue(select_1.selectActiveValue(wrapper));
};
/**
 * @deprecated
 */
exports.mapNewExtendedEntity = function (editableEntity) {
    return mapper_generic_1.GenericMappers.entityAsExtendedEntity(editableEntity);
};
/**
 * @stable [23.12.2019]
 * @param {IExtendedEntity<TEntity>} extendedEntity
 * @returns {IApiEntity<TEntity>}
 */
exports.mapApiEntity = function (extendedEntity) {
    var changes = extendedEntity.changes, entity = extendedEntity.entity, originalEntity = extendedEntity.originalEntity;
    var entityId = select_1.selectEntityId(entity);
    var newEntity = R.isNil(entityId);
    return filter_1.defValuesFilter({
        changes: changes,
        diff: newEntity ? entity : changes,
        entity: entity,
        entityId: entityId,
        newEntity: newEntity,
        originalEntity: originalEntity,
    });
};
/**
 * @stable [22.04.2020]
 * @param {INamedEntity} entity
 * @returns {IExtendedLabeledValueEntity}
 */
exports.mapExtendedLabeledValueEntity = function (entity) {
    return filter_1.defValuesFilter({
        value: entity.id,
        label: entity.name || String(entity.id),
        rawData: entity,
    });
};
/**
 * @stable [25.11.2019]
 * @param {string[]} queue
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
exports.hasQueueOperations = function (queue) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    return !R.isEmpty(R.intersection(queue, operations.map(function (operation) { return (type_1.TypeUtils.isString(operation)
        ? operation
        : operation.id); })));
};
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
exports.hasTransportWrapperQueueOperations = function (entity) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    return exports.hasQueueOperations.apply(void 0, [exports.selectTransportWrapperQueue(entity)].concat(operations));
};
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.isApplicationInProgress = function (entity) { return wrapper_1.inProgress(entity); };
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.doesApplicationErrorExist = function (entity) { return wrapper_1.doesErrorExist(entity); };
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.isApplicationMessageVisible = function (entity) {
    return exports.isApplicationInProgress(entity) || exports.doesApplicationErrorExist(entity) || !wrapper_1.isReady(entity);
};
/**
 * @stable [14.04.2020]
 * @param {IGenericStoreEntity<TDictionaries>} entity
 * @returns {IGenericStoreEntity<TDictionaries>}
 */
exports.mapStoreEntity = function (entity) {
    return (__assign({}, exports.mapChannelWrapperEntity(entity), exports.mapDictionariesWrapperEntity(entity), mapper_generic_1.GenericMappers.layoutEntity(entity), exports.mapNotificationWrapperEntity(entity), mapper_generic_1.GenericMappers.sectionNameWrapper(entity), exports.mapStackWrapperEntity(entity), exports.mapTransportWrapperEntity(entity), exports.mapUserWrapperEntity(entity)));
};
/**
 * @container-props-mapper
 * @stable [13.04.2020]
 *
 * @param {IFormTabPanelContainerProps} props
 * @returns {IFormTabPanelContainerProps}
 */
exports.mapFormTabPanelContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), mapper_generic_1.GenericMappers.formEntity(props)));
};
/**
 * @container-props-mapper
 * @stable [23.04.2020]
 *
 * @param {IFormEntity<TEntity>} props
 * @param {IGenericContainer} proxyContainer
 * @returns {IUnsavedFormChangesDialogContainerProps}
 */
exports.mapUnsavedFormChangesDialogContainerProps = function (props, proxyContainer) {
    return ({
        dialogConfiguration: mapper_generic_1.GenericMappers.formEntity(props),
        proxyContainer: proxyContainer,
    });
};
var mapHeaderProps = function (props) { return exports.mapStoreEntity(props); };
/**
 * @stable [05.05.2020]
 */
var Mappers = /** @class */ (function () {
    function Mappers() {
    }
    Mappers.dictionaryEntityAsSelectEntity = mapper_generic_1.GenericMappers.dictionaryEntityAsSelectEntity; /* @stable [19.05.2020] */
    Mappers.dictionaryEntityAsSelectOptionEntities = mapper_generic_1.GenericMappers.dictionaryEntityAsSelectOptionEntities; /* @stable [19.05.2020] */
    Mappers.entityAsExtendedEntity = mapper_generic_1.GenericMappers.entityAsExtendedEntity; /* @stable [10.05.2020] */
    Mappers.entityAsExtendedFormEntity = mapper_generic_1.GenericMappers.entityAsExtendedFormEntity; /* @stable [10.05.2020] */
    Mappers.filterFormDialogContainerProps = mapper_component_1.ComponentMappers.filterFormDialogContainerProps; /* @stable [10.05.2020] */
    Mappers.filterFormDialogSecondaryFilterContainerProps = mapper_component_1.ComponentMappers.filterFormDialogSecondaryFilterContainerProps; /* @stable [10.05.2020] */
    Mappers.form = mapper_generic_1.GenericMappers.form; /* @stable [08.05.2020] */
    Mappers.formContainerProps = mapper_component_1.ComponentMappers.formContainerProps; /* @stable [08.05.2020] */
    Mappers.formContainerPropsAsFormProps = mapper_component_1.ComponentMappers.formContainerPropsAsFormProps; /* @stable [09.05.2020] */
    Mappers.formEntity = mapper_generic_1.GenericMappers.formEntity; /* @stable [08.05.2020] */
    Mappers.formPrimaryFilterContainerProps = mapper_component_1.ComponentMappers.formPrimaryFilterContainerProps; /* @stable [10.05.2020] */
    Mappers.fullSearchFilter = mapper_generic_1.GenericMappers.fullSearchFilter; /* @stable [10.05.2020] */
    Mappers.headerProps = mapHeaderProps;
    Mappers.listContainerProps = mapper_component_1.ComponentMappers.listContainerProps; /* @stable [10.05.2020] */
    Mappers.listEntity = mapper_generic_1.GenericMappers.listEntity; /* @stable [08.05.2020] */
    Mappers.listEntityAsDisabled = mapper_generic_1.GenericMappers.listEntityAsDisabled; /* @stable [08.05.2020] */
    Mappers.listEntityAsPagedEntity = mapper_generic_1.GenericMappers.listEntityAsPagedEntity; /* @stable [08.05.2020] */
    Mappers.listSelectedEntityAsExtendedFormEntity = mapper_generic_1.GenericMappers.listSelectedEntityAsExtendedFormEntity; /* @stable [08.05.2020] */
    Mappers.optionEntitiesAsSelectOptionEntities = mapper_generic_1.GenericMappers.optionEntitiesAsSelectOptionEntities; /* @stable [19.05.2020] */
    Mappers.pagedEntity = mapper_generic_1.GenericMappers.pagedEntity;
    Mappers.pageToolbarContainerProps = mapper_component_1.ComponentMappers.pageToolbarContainerProps;
    Mappers.paginatedEntity = mapper_generic_1.GenericMappers.paginatedEntity;
    Mappers.placeFieldProps = mapper_component_1.ComponentMappers.placeFieldProps; /* @stable [19.05.2020] */
    Mappers.primaryFilterEntityAsPrimaryFilterExtendedFormEntity = mapper_generic_1.GenericMappers.primaryFilterEntityAsPrimaryFilterExtendedFormEntity; /* @stable [10.05.2020] */
    Mappers.queryFilterEntity = mapper_generic_1.GenericMappers.queryFilterEntity;
    Mappers.queryFilterEntityAsQuery = mapper_generic_1.GenericMappers.queryFilterEntityAsQuery;
    Mappers.searchToolbarContainerProps = mapper_component_1.ComponentMappers.searchToolbarContainerProps;
    Mappers.secondaryFilterEntityAsSecondaryFilterExtendedFormEntity = mapper_generic_1.GenericMappers.secondaryFilterEntityAsSecondaryFilterExtendedFormEntity; /* @stable [10.05.2020] */
    Mappers.sectionNameWrapper = mapper_generic_1.GenericMappers.sectionNameWrapper;
    Mappers.selectableHoveredEntity = mapSelectableHoveredEntity;
    Mappers.selectedExtendedFormEntityAsFinalEntity = mapper_generic_1.GenericMappers.listSelectedExtendedFormEntityAsFinalEntity; /* @stable [10.05.2020] */
    Mappers.toolbarToolsContainerProps = mapper_component_1.ComponentMappers.toolbarToolsContainerProps; /* @stable [09.05.2020] */
    Mappers.toolbarToolsContainerPropsAsToolbarTools = mapper_component_1.ComponentMappers.toolbarToolsContainerPropsAsToolbarTools; /* @stable [10.05.2020] */
    Mappers.toolbarToolsSecondaryFilterContainerProps = mapper_component_1.ComponentMappers.toolbarToolsSecondaryFilterContainerProps; /* @stable [10.05.2020] */
    return Mappers;
}());
exports.Mappers = Mappers;
//# sourceMappingURL=mapper.js.map