import { IEffectsAction } from 'redux-effects-promise';
import { IActiveValueWrapper, IChangesWrapper, IChannelWrapper, IDataWrapper, IDictionariesWrapper, IDiffWrapper, IDirectionsWrapper, IDirtyWrapper, IElementWrapper, IEntity, IEntityIdTWrapper, IEntityWrapper, IFilterWrapper, IFormWrapper, ILayoutWrapper, IListWrapper, INotificationWrapper, IPayloadWrapper, IPreventEffectsWrapper, IPrimaryFilterWrapper, IQueryFilterWrapper, IQueryWrapper, IQueueWrapper, IRawDataWrapper, ISecondaryFilterWrapper, ISectionNameWrapper, ISelectedWrapper, IStackWrapper, ITabPanelWrapper, ITokenWrapper, ITransportWrapper, ITypeWrapper, IUserWrapper, IValidWrapper } from '../definitions.interface';
import { IFormEntity, IListEntity, IPreviousActionWrapperEntity, IQueryFilterEntity, IReduxHolderLayoutEntity, IReduxHolderStackEntity, IReduxStackItemEntity, LayoutModesEnum, ToolbarToolsEnum } from '../definition';
/**
 * @stable [30.03.2020]
 * @param {IQueueWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectQueue: <TValue>(wrapper: IQueueWrapper<TValue>) => TValue;
/**
 * @stable [30.03.2020]
 * @param {IRawDataWrapper<TData>} wrapper
 * @returns {TData}
 */
export declare const selectRawData: <TValue = any>(wrapper: IRawDataWrapper<TValue>) => TValue;
/**
 * @stable [06.04.2020]
 * @param {IElementWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectElement: <TValue = any>(wrapper: IElementWrapper<TValue>) => TValue;
/**
 * @stable [27.03.2020]
 * @param {IEntityIdTWrapper} entity
 * @returns {EntityIdT}
 */
export declare const selectEntityId: (entity: IEntityIdTWrapper) => string | number;
/**
 * @stable [29.02.2020]
 * @param {IFormWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectForm: <TValue>(wrapper: IFormWrapper<TValue>) => TValue;
/**
 * @stable [26.03.2020]
 * @param {ITypeWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectType: <TValue>(wrapper: ITypeWrapper<TValue>) => TValue;
/**
 * @stable [29.02.2020]
 * @param {ITokenWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectToken: <TValue = string>(wrapper: ITokenWrapper<TValue>) => TValue;
/**
 * @stable [05.03.2020]
 * @param {IChangesWrapper<TResult>} entity
 * @returns {TResult}
 */
export declare const selectChanges: <TResult = IEntity>(entity: IChangesWrapper<TResult>) => TResult;
/**
 * @stable [13.04.2020]
 * @param {IDiffWrapper<TResult>} entity
 * @returns {TResult}
 */
export declare const selectDiff: <TResult = IEntity>(entity: IDiffWrapper<TResult>) => TResult;
/**
 * @stable [05.03.2020]
 * @param {IEntityWrapper<TResult>} entity
 * @returns {TResult}
 */
export declare const selectEntity: <TResult = IEntity>(entity: IEntityWrapper<TResult>) => TResult;
/**
 * @stable [05.03.2020]
 * @param {IDataWrapper<TData>} wrapper
 * @returns {TData}
 */
export declare const selectData: <TData>(wrapper: IDataWrapper<TData>) => TData;
/**
 * @stable [12.04.2020]
 * @param {IActiveValueWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectActiveValue: <TValue>(wrapper: IActiveValueWrapper<TValue>) => TValue;
/**
 * @stable [30.03.2020]
 * @param {IPayloadWrapper<TPayload>} wrapper
 * @returns {TPayload}
 */
export declare const selectPayload: <TPayload>(wrapper: IPayloadWrapper<TPayload>) => TPayload;
/**
 * @stable [30.03.2020]
 * @param {IEffectsAction} action
 * @returns {TPayload}
 */
export declare const selectDataPayloadFromAction: <TPayload>(action: IEffectsAction) => TPayload;
/**
 * @stable [27.03.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
export declare const selectValid: (wrapper: IValidWrapper) => boolean;
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
export declare const selectValidFromAction: (wrapper: IEffectsAction) => boolean;
/**
 * @stable [26.03.2020]
 * @param {IPreventEffectsWrapper} wrapper
 * @returns {boolean}
 */
export declare const selectPreventEffects: (wrapper: IPreventEffectsWrapper<boolean>) => boolean;
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
export declare const selectPreventEffectsFromAction: (wrapper: IEffectsAction) => boolean;
/**
 *
 * @param {IPreviousActionWrapperEntity} wrapper
 * @returns {IEffectsAction}
 */
export declare const selectPreviousAction: (wrapper: IPreviousActionWrapperEntity) => IEffectsAction;
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {IEffectsAction}
 */
export declare const selectPreviousActionFromAction: (wrapper: IEffectsAction) => IEffectsAction;
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} action
 * @returns {string}
 */
export declare const selectPreviousActionTypeFromAction: (action: IEffectsAction) => string;
/**
 * @stable [27.03.2020]
 * @param {ISelectedWrapper<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
export declare const selectSelected: <TEntity extends IEntity>(entity: ISelectedWrapper<TEntity>) => TEntity;
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
export declare const selectSelectedEntityFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => TEntity;
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {EntityIdT}
 */
export declare const selectSelectedEntityIdFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => string | number;
/**
 * @stable [30.03.2020]
 * @param {IUserWrapper<TUser>} wrapper
 * @returns {TUser}
 */
export declare const selectUser: <TUser>(wrapper: IUserWrapper<TUser>) => TUser;
/**
 * @stable [14.04.2020]
 * @param {INotificationWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
export declare const selectNotification: <TEntity>(wrapper: INotificationWrapper<TEntity>) => TEntity;
/**
 * @stable [14.04.2020]
 * @param {IChannelWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
export declare const selectChannel: <TEntity>(wrapper: IChannelWrapper<TEntity>) => TEntity;
/**
 * @stable [30.03.2020]
 * @param {ITransportWrapper<TTransport>} wrapper
 * @returns {TTransport}
 */
export declare const selectTransport: <TTransport>(wrapper: ITransportWrapper<TTransport>) => TTransport;
/**
 * @stable [30.03.2020]
 * @param {IDictionariesWrapper<TDictionaries>} wrapper
 * @returns {TDictionaries}
 */
export declare const selectDictionaries: <TDictionaries>(wrapper: IDictionariesWrapper<TDictionaries>) => TDictionaries;
/**
 * @stable [06.05.2020]
 */
export declare class Selectors {
    static readonly activeToolbarToolsFromDirtyWrapper: (wrapper: IDirtyWrapper) => ToolbarToolsEnum[];
    static readonly changes: <TResult = IEntity>(entity: IChangesWrapper<TResult>) => TResult;
    static readonly data: <TData>(wrapper: IDataWrapper<TData>) => TData;
    static readonly directions: <TValue>(wrapper: IDirectionsWrapper<TValue>) => TValue;
    static readonly entity: <TResult = IEntity>(entity: IEntityWrapper<TResult>) => TResult;
    static readonly filter: <TValue = string>(wrapper: IFilterWrapper<TValue>) => TValue;
    static readonly form: <TValue>(wrapper: IFormWrapper<TValue>) => TValue;
    static readonly formEntityChanges: <TEntity = IEntity>(entity: IFormEntity<TEntity>) => TEntity;
    static readonly layout: <TEntity>(wrapper: ILayoutWrapper<TEntity>) => TEntity;
    static readonly layoutMode: (entity: IReduxHolderLayoutEntity<import("core/definition/layout-definition.interface").IReduxLayoutEntity>) => LayoutModesEnum;
    static readonly list: <TValue>(wrapper: IListWrapper<TValue>) => TValue;
    static readonly listProgress: (entity: IListEntity<IEntity, any>) => boolean;
    static readonly listRawData: <TRawData = any>(entity: IListEntity<IEntity, any>) => TRawData;
    static readonly listSelectedEntity: <TEntity extends IEntity>(entity: IListEntity<TEntity, any>) => TEntity;
    static readonly mergedLayoutMode: (merged: IReduxHolderLayoutEntity<import("core/definition/layout-definition.interface").IReduxLayoutEntity>, original: IReduxHolderLayoutEntity<import("core/definition/layout-definition.interface").IReduxLayoutEntity>) => LayoutModesEnum;
    static readonly primaryFilter: <TValue>(wrapper: IPrimaryFilterWrapper<TValue>) => TValue;
    static readonly query: (wrapper: IQueryWrapper<string>) => string;
    static readonly queryFilter: <TValue = string>(wrapper: IQueryFilterWrapper<TValue>) => TValue;
    static readonly queryFilterEntityQuery: (entity: IQueryFilterEntity) => string;
    static readonly secondaryFilter: <TValue>(wrapper: ISecondaryFilterWrapper<TValue>) => TValue;
    static readonly sectionName: (wrapper: ISectionNameWrapper) => string;
    static readonly stack: <TEntity>(wrapper: IStackWrapper<TEntity>) => TEntity;
    static readonly stackItemEntities: (entity: IReduxHolderStackEntity<import("core/definition/stack-definition.interface").IReduxStackEntity>) => IReduxStackItemEntity[];
    static readonly tabPanel: <TTabPanel>(entity: ITabPanelWrapper<TTabPanel>) => TTabPanel;
}
