"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var nvl_1 = require("./nvl");
var definition_1 = require("../definition");
var cond_1 = require("./cond");
var wrapper_1 = require("./wrapper");
/**
 * @stable [30.03.2020]
 * @param {IQueueWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectQueue = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.queue;
};
/**
 * @stable [30.03.2020]
 * @param {IRawDataWrapper<TData>} wrapper
 * @returns {TData}
 */
exports.selectRawData = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.rawData;
};
/**
 * @stable [06.04.2020]
 * @param {IElementWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectElement = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.element;
};
/**
 * @stable [27.03.2020]
 * @param {IEntityIdTWrapper} entity
 * @returns {EntityIdT}
 */
exports.selectEntityId = function (entity) { return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.id; };
/**
 * @stable [29.02.2020]
 * @param {IFormWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectForm = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.form; };
/**
 * @stable [08.05.2020]
 * @param {ISecondaryFilterWrapper<TValue>} wrapper
 * @returns {TValue}
 */
var selectSecondaryFilter = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.secondaryFilter;
};
/**
 * @stable [10.05.2020]
 * @param {IPrimaryFilterWrapper<TValue>} wrapper
 * @returns {TValue}
 */
var selectPrimaryFilter = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.primaryFilter;
};
/**
 * @stable [27.03.2020]
 * @param {IListWrapper<TValue>} wrapper
 * @returns {TValue}
 */
var selectList = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.list;
};
/**
 * @stable [09.04.2020]
 * @param {IFilterWrapper<TValue>} wrapper
 * @returns {TValue}
 */
var selectFilter = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.filter;
};
/**
 * @stable [07.05.2020]
 * @param {IQueryFilterWrapper<TValue>} wrapper
 * @returns {TValue}
 */
var selectQueryFilter = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.queryFilter;
};
/**
 * @stable [26.03.2020]
 * @param {ITypeWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectType = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.type;
};
/**
 * @stable [29.02.2020]
 * @param {ITokenWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectToken = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.token;
};
/**
 * @stable [05.03.2020]
 * @param {IChangesWrapper<TResult>} entity
 * @returns {TResult}
 */
exports.selectChanges = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.changes;
};
/**
 * @stable [13.04.2020]
 * @param {IDiffWrapper<TResult>} entity
 * @returns {TResult}
 */
exports.selectDiff = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.diff;
};
/**
 * @stable [05.03.2020]
 * @param {IEntityWrapper<TResult>} entity
 * @returns {TResult}
 */
exports.selectEntity = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.entity;
};
/**
 * @stable [05.03.2020]
 * @param {IDataWrapper<TData>} wrapper
 * @returns {TData}
 */
exports.selectData = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.data;
};
/**
 * @stable [12.04.2020]
 * @param {IActiveValueWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectActiveValue = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.activeValue;
};
/**
 * @stable [30.03.2020]
 * @param {IPayloadWrapper<TPayload>} wrapper
 * @returns {TPayload}
 */
exports.selectPayload = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.payload;
};
/**
 * @stable [30.03.2020]
 * @param {IEffectsAction} action
 * @returns {TPayload}
 */
exports.selectDataPayloadFromAction = function (action) {
    return exports.selectPayload(exports.selectData(action));
};
/**
 * @stable [27.03.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
exports.selectValid = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.valid;
};
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
exports.selectValidFromAction = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : exports.selectValid(wrapper.data);
};
/**
 * @stable [26.03.2020]
 * @param {IPreventEffectsWrapper} wrapper
 * @returns {boolean}
 */
exports.selectPreventEffects = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.preventEffects;
};
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
exports.selectPreventEffectsFromAction = function (wrapper) {
    return R.isNil(wrapper)
        ? definitions_interface_1.UNDEF
        : nvl_1.NvlUtils.coalesce(exports.selectPreventEffects(wrapper.data), exports.selectPreventEffects(wrapper.initialData));
};
/**
 *
 * @param {IPreviousActionWrapperEntity} wrapper
 * @returns {IEffectsAction}
 */
exports.selectPreviousAction = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.previousAction;
};
/**
 * @stable [08.05.2020]
 * @param {IListEntity} entity
 * @returns {boolean}
 */
var selectListProgress = function (entity) { return wrapper_1.inProgress(selectList(entity)); };
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {IEffectsAction}
 */
exports.selectPreviousActionFromAction = function (wrapper) {
    return R.isNil(wrapper)
        ? definitions_interface_1.UNDEF
        : nvl_1.NvlUtils.coalesce(exports.selectPreviousAction(wrapper.data), exports.selectPreviousAction(wrapper.initialData));
};
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} action
 * @returns {string}
 */
exports.selectPreviousActionTypeFromAction = function (action) {
    return cond_1.ifNotNilThanValue(exports.selectPreviousActionFromAction(action), function (previousAction) { return exports.selectType(previousAction); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [27.03.2020]
 * @param {ISelectedWrapper<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
exports.selectSelected = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.selected;
};
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
exports.selectSelectedEntityFromAction = function (action) {
    return cond_1.ifNotNilThanValue(exports.selectData(action), function (data) { return exports.selectSelected(data); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {EntityIdT}
 */
exports.selectSelectedEntityIdFromAction = function (action) {
    return cond_1.ifNotNilThanValue(exports.selectSelectedEntityFromAction(action), function (entity) { return exports.selectEntityId(entity); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [30.03.2020]
 * @param {IUserWrapper<TUser>} wrapper
 * @returns {TUser}
 */
exports.selectUser = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.user;
};
/**
 * @stable [30.03.2020]
 * @param {IStackWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
var selectStack = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.stack;
};
/**
 * @stable [14.04.2020]
 * @param {INotificationWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
exports.selectNotification = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.notification;
};
/**
 * @stable [24.04.2020]
 * @param {IQueryWrapper} wrapper
 * @returns {string}
 */
var selectQuery = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.query; };
/**
 * @stable [14.04.2020]
 * @param {ILayoutWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
var selectLayout = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.layout;
};
/**
 * @stable [21.05.2020]
 * @param {IModeWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
var selectMode = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.mode;
};
/**
 * @stable [14.04.2020]
 * @param {IChannelWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
exports.selectChannel = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.channel;
};
/**
 * @stable [30.03.2020]
 * @param {ITransportWrapper<TTransport>} wrapper
 * @returns {TTransport}
 */
exports.selectTransport = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.transport;
};
/**
 * @stable [30.03.2020]
 * @param {IDictionariesWrapper<TDictionaries>} wrapper
 * @returns {TDictionaries}
 */
exports.selectDictionaries = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.dictionaries;
};
/**
 * @stable [30.03.2020]
 * @param {ISectionNameWrapper} wrapper
 * @returns {string}
 */
var selectSectionName = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.sectionName; };
/**
 * @stable [17.05.2020]
 * @param {ITabPanelWrapper<TTabPanel>} entity
 * @returns {TTabPanel}
 */
var selectTabPanel = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.tabPanel;
};
/**
 * @stable [08.05.2020]
 * @param {IListEntity<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
var selectListSelectedEntity = function (entity) {
    return exports.selectSelected(selectList(entity));
};
/**
 * @stable [08.05.2020]
 * @param {IDirectionsWrapper<TValue>} wrapper
 * @returns {TValue}
 */
var selectDirections = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.directions;
};
/**
 * @stable [08.05.2020]
 * @param {IListEntity} entity
 * @returns {TRawData}
 */
var selectListRawData = function (entity) { return exports.selectRawData(selectList(entity)); };
/**
 * @stable [08.05.2020]
 * @param {IFormEntity<TEntity>} entity
 * @returns {TEntity}
 */
var selectFormEntityChanges = function (entity) {
    return exports.selectChanges(exports.selectForm(entity));
};
/**
 * @stable [08.05.2020]
 * @param {IDirtyWrapper} wrapper
 * @returns {ToolbarToolsEnum[]}
 */
var selectActiveToolbarToolsFromDirtyWrapper = function (wrapper) {
    return wrapper_1.isDirty(wrapper)
        ? [definition_1.ToolbarToolsEnum.FILTER]
        : [];
};
/**
 * @stable [07.05.2020]
 * @param {IQueryFilterEntity} entity
 * @returns {string}
 */
var selectQueryFilterEntityQuery = function (entity) {
    return selectQuery(selectQueryFilter(entity));
};
/**
 * @stable [21.05.2020]
 * @param {IReduxHolderStackEntity} entity
 * @returns {IReduxStackItemEntity[]}
 */
var selectStackItemEntities = function (entity) { return selectStack(selectStack(entity)); };
/**
 * @stable [21.05.2020]
 * @param {IReduxHolderLayoutEntity} entity
 * @returns {LayoutModesEnum}
 */
var selectLayoutMode = function (entity) { return selectMode(selectLayout(entity)); };
/**
 * @stable [21.05.2020]
 * @param {IReduxHolderLayoutEntity} merged
 * @param {IReduxHolderLayoutEntity} original
 * @returns {LayoutModesEnum}
 */
var selectMergedLayoutMode = function (merged, original) {
    return nvl_1.NvlUtils.nvl(selectLayoutMode(merged), selectLayoutMode(original));
};
/**
 * @stable [06.05.2020]
 */
var Selectors = /** @class */ (function () {
    function Selectors() {
    }
    Selectors.activeToolbarToolsFromDirtyWrapper = selectActiveToolbarToolsFromDirtyWrapper; /* @stable [08.05.2020] */
    Selectors.changes = exports.selectChanges;
    Selectors.data = exports.selectData; /* @stable [19.05.2020] */
    Selectors.directions = selectDirections; /* @stable [08.05.2020] */
    Selectors.entity = exports.selectEntity;
    Selectors.filter = selectFilter;
    Selectors.form = exports.selectForm; /* @stable [11.05.2020] */
    Selectors.formEntityChanges = selectFormEntityChanges; /* @stable [11.05.2020] */
    Selectors.layout = selectLayout; /* @stable [08.05.2020] */
    Selectors.layoutMode = selectLayoutMode; /* @stable [21.05.2020] */
    Selectors.list = selectList;
    Selectors.listProgress = selectListProgress; /* @stable [08.05.2020] */
    Selectors.listRawData = selectListRawData; /* @stable [08.05.2020] */
    Selectors.listSelectedEntity = selectListSelectedEntity; /* @stable [08.05.2020] */
    Selectors.mergedLayoutMode = selectMergedLayoutMode; /* @stable [21.05.2020] */
    Selectors.primaryFilter = selectPrimaryFilter; /* @stable [10.05.2020] */
    Selectors.query = selectQuery;
    Selectors.queryFilter = selectQueryFilter;
    Selectors.queryFilterEntityQuery = selectQueryFilterEntityQuery;
    Selectors.secondaryFilter = selectSecondaryFilter; /* @stable [09.05.2020] */
    Selectors.sectionName = selectSectionName;
    Selectors.stack = selectStack; /* @stable [21.05.2020] */
    Selectors.stackItemEntities = selectStackItemEntities; /* @stable [21.05.2020] */
    Selectors.tabPanel = selectTabPanel; /* @stable [17.05.2020] */
    return Selectors;
}());
exports.Selectors = Selectors;
//# sourceMappingURL=select.js.map